@@ -14,11 +14,10 @@
 # limitations under the License.
 """Tools for making the most of GcsApi metadata."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import copy
+import datetime
+import enum
 from typing import List
 
 from apitools.base.py import encoding
@@ -34,6 +33,7 @@ from googlecloudsdk.command_lib.storage import storage_url
 from googlecloudsdk.command_lib.storage import user_request_args_factory
 from googlecloudsdk.command_lib.storage.resources import gcs_resource_reference
 from googlecloudsdk.command_lib.storage.resources import resource_reference
+from googlecloudsdk.command_lib.storage.resources import resource_util
 from googlecloudsdk.core import properties
 
 
@@ -44,7 +44,16 @@ from googlecloudsdk.core import properties
 # object ACL.
 PRIVATE_DEFAULT_OBJECT_ACL = apis.GetMessagesModule(
     'storage', 'v1').ObjectAccessControl(id='PRIVATE_DEFAULT_OBJ_ACL')
+CONTEXT_TYPE_LITERAL = 'type'
+CONTEXT_VALUE_LITERAL = 'value'
+CONTEXT_CREATE_TIME_LITERAL = 'createTime'
+CONTEXT_UPDATE_TIME_LITERAL = 'updateTime'
 
+_ENCRYPTION_ENFORCEMENT_FIELDS = (
+    'googleManagedEncryptionEnforcementConfig',
+    'customerManagedEncryptionEnforcementConfig',
+    'customerSuppliedEncryptionEnforcementConfig',
+)
 _NO_TRANSFORM = 'no-transform'
 
 
@@ -60,10 +69,33 @@ def _message_to_dict(message):
   return None
 
 
+class ContextType(enum.Enum):
+  """Used to distinguish between custom and google generated contexts."""
+  CUSTOM = 'CUSTOM'
+
+
+class MethodType(enum.Enum):
+  """Configuration for copying metadata."""
+  OBJECT_PATCH = 'object_patch'
+  OBJECT_REWRITE = 'object_rewrite'
+  OBJECT_COMPOSE = 'object_compose'
+  OBJECT_INSERT = 'object_insert'
+
+
+def get_context_value_dict_from_value(value):
+  """Returns the context value dict based on the value.
+
+  Args:
+    value (str): The value to be parsed.
+  """
+  return {CONTEXT_VALUE_LITERAL: value}
+
+
 def copy_object_metadata(source_metadata,
                          destination_metadata,
                          request_config,
-                         should_deep_copy=False):
+                         should_deep_copy=False,
+                         method_type=MethodType.OBJECT_REWRITE):
   """Copies specific metadata from source_metadata to destination_metadata.
 
   The API manually generates metadata for destination objects most of the time,
@@ -76,6 +108,8 @@ def copy_object_metadata(source_metadata,
       about the copy operation.
     should_deep_copy (bool): Copy all metadata, removing fields the
       backend must generate and preserving destination address.
+    method_type (MethodType): The type of method being used to copy the object,
+        defaulting to MethodType.OBJECT_REWRITE.
 
   Returns:
     New destination metadata with data copied from source (messages.Object).
@@ -109,6 +143,15 @@ def copy_object_metadata(source_metadata,
     destination_metadata.customTime = source_metadata.customTime
     destination_metadata.md5Hash = source_metadata.md5Hash
     destination_metadata.metadata = copy.deepcopy(source_metadata.metadata)
+    if method_type != MethodType.OBJECT_COMPOSE:
+      # Currently this method is being called for preparing request for
+      # object.compose, and object.rewrite.
+      # The compose method pick up certain attributes from the first object
+      # speicified in the compose request, and ignore the rest,
+      # but we do not want this in case of object contexts, because instead we
+      # want the merged contexts from all the objects present in the compose
+      # request.
+      destination_metadata.contexts = copy.deepcopy(source_metadata.contexts)
 
   return destination_metadata
 
@@ -126,6 +169,37 @@ def get_apitools_metadata_from_url(cloud_url):
         generation=generation)
 
 
+def _get_encryption_enforcement_config(encryption):
+  """Extracts and converts encryption enforcement config from bucket metadata's encryption field.
+
+  Args:
+    encryption (messages.Bucket.Encryption): The bucket metadata's encryption.
+
+  Returns:
+    dict or None: The encryption enforcement config as a dictionary, or None.
+  """
+  encryption_enforcement = None
+  if encryption and (
+      encryption.googleManagedEncryptionEnforcementConfig
+      or encryption.customerManagedEncryptionEnforcementConfig
+      or encryption.customerSuppliedEncryptionEnforcementConfig
+  ):
+    encryption_enforcement = {}
+    if encryption.googleManagedEncryptionEnforcementConfig:
+      encryption_enforcement['gmekEnforcement'] = _message_to_dict(
+          encryption.googleManagedEncryptionEnforcementConfig
+      )
+    if encryption.customerManagedEncryptionEnforcementConfig:
+      encryption_enforcement['cmekEnforcement'] = _message_to_dict(
+          encryption.customerManagedEncryptionEnforcementConfig
+      )
+    if encryption.customerSuppliedEncryptionEnforcementConfig:
+      encryption_enforcement['csekEnforcement'] = _message_to_dict(
+          encryption.customerSuppliedEncryptionEnforcementConfig
+      )
+  return encryption_enforcement
+
+
 def get_bucket_resource_from_metadata(metadata):
   """Helper method to generate a BucketResource instance from GCS metadata.
 
@@ -136,7 +210,8 @@ def get_bucket_resource_from_metadata(metadata):
     BucketResource with properties populated by metadata.
   """
   url = storage_url.CloudUrl(
-      scheme=storage_url.ProviderPrefix.GCS, bucket_name=metadata.name)
+      scheme=storage_url.ProviderPrefix.GCS, bucket_name=metadata.name
+  )
 
   if metadata.autoclass and metadata.autoclass.enabled:
     autoclass_enabled_time = metadata.autoclass.toggleTime
@@ -145,7 +220,9 @@ def get_bucket_resource_from_metadata(metadata):
 
   uniform_bucket_level_access = getattr(
       getattr(metadata.iamConfiguration, 'uniformBucketLevelAccess', None),
-      'enabled', None)
+      'enabled',
+      None,
+  )
 
   return gcs_resource_reference.GcsBucketResource(
       url,
@@ -158,6 +235,9 @@ def get_bucket_resource_from_metadata(metadata):
       default_acl=_message_to_dict(metadata.defaultObjectAcl),
       default_event_based_hold=metadata.defaultEventBasedHold or None,
       default_kms_key=getattr(metadata.encryption, 'defaultKmsKeyName', None),
+      encryption_enforcement_config=_get_encryption_enforcement_config(
+          metadata.encryption
+      ),
       default_storage_class=metadata.storageClass,
       etag=metadata.etag,
       labels=_message_to_dict(metadata.labels),
@@ -239,6 +319,88 @@ def get_anywhere_cache_resource_from_metadata(metadata):
   )
 
 
+def parse_custom_contexts_dict_from_resource_contexts_dict(
+    resource_contexts_dict,
+):
+  """Parses custom contexts from resource contexts for request purposes.
+
+  Examples:
+    resource_contexts_dict={
+        'key': {
+            'value': 'value',
+            'createTime': '2025-01-01T00:00:00Z',
+            'updateTime': '2025-01-01T00:00:00Z',
+            'type': 'CUSTOM'
+        }
+        'key2': {
+            'value': 'value2',
+            'createTime': '2025-01-01T00:00:00Z',
+            'updateTime': '2025-01-01T00:00:00Z',
+            'type': 'GENERATED'
+        }
+    } would return the following dictionary:
+    {
+        'custom': {
+          'key': {
+              'value': 'value',
+          }
+        }
+    }
+
+  Note: the method intentionally drops all other fields other than the context
+  value, as they are internal only fields, or not meant to be sent to the API.
+
+  Args:
+    resource_contexts_dict (dict): The resource contexts dict to parse.
+
+  Returns:
+    a dictionary of contexts in apitools format for request purposes.
+  """
+  if resource_contexts_dict is None:
+    return resource_contexts_dict
+  custom_contexts_dict = {}
+  for key, value in resource_contexts_dict.items():
+    context_type = value.get(CONTEXT_TYPE_LITERAL, None)
+    context_value = value.get(CONTEXT_VALUE_LITERAL, None)
+    if context_type == ContextType.CUSTOM.value:
+      custom_contexts_dict[key] = (
+          get_context_value_dict_from_value(context_value)
+      )
+  return get_contexts_dict_from_custom_contexts_dict(custom_contexts_dict)
+
+
+def _parse_contexts_from_object_metadata(metadata):
+  """Returns parsed contexts from apitools object metadata.
+
+  apitools object metadata separates custom contexts, and google generated
+  contexts (coming in 2026) into separate maps, However CLI along with other
+  clients uses a single map with a type field to distinguish between the two.
+  This method parses the apitools object metadata into the single map format
+  used by CLI and other clients.
+
+  Args:
+    metadata (messages.Object): The object metadata to parse contexts from.
+  """
+  if not (metadata.contexts and metadata.contexts.custom):
+    return None
+
+  custom_contexts = _message_to_dict(metadata.contexts.custom)
+  parsed_contexts = {}
+  for key, value in custom_contexts.items():
+    context_value_dict = {}
+    for field in [CONTEXT_CREATE_TIME_LITERAL, CONTEXT_UPDATE_TIME_LITERAL]:
+      if field in value:
+        context_value_dict[field] = (
+            resource_util.get_formatted_string_from_datetime_object(
+                datetime.datetime.fromisoformat(value[field])
+            )
+        )
+    context_value_dict[CONTEXT_VALUE_LITERAL] = value[CONTEXT_VALUE_LITERAL]
+    context_value_dict[CONTEXT_TYPE_LITERAL] = ContextType.CUSTOM.value
+    parsed_contexts[key] = context_value_dict
+  return parsed_contexts
+
+
 def get_object_resource_from_metadata(metadata):
   """Helper method to generate a ObjectResource instance from GCS metadata.
 
@@ -276,6 +438,7 @@ def get_object_resource_from_metadata(metadata):
       content_type=metadata.contentType,
       crc32c_hash=metadata.crc32c,
       creation_time=metadata.timeCreated,
+      contexts=_parse_contexts_from_object_metadata(metadata),
       custom_fields=_message_to_dict(metadata.metadata),
       custom_time=metadata.customTime,
       decryption_key_hash_sha256=decryption_key_hash_sha256,
@@ -472,6 +635,75 @@ def _get_labels_object_with_added_and_removed_labels(labels_object,
   return messages.Bucket.LabelsValue(additionalProperties=new_labels)
 
 
+def _should_clear_encryption_field(encryption_metadata) -> bool:
+  """Checks if the entire encryption field should be cleared.
+
+  The encryption field should be cleared if it exists, but all its subfields
+  are None or unset.
+
+  Args:
+    encryption_metadata (messages.Bucket.EncryptionValue|None): The bucket
+      metadata's encryption field.
+
+  Returns:
+    bool: True if the encryption field should be cleared, False otherwise.
+  """
+  return encryption_metadata is not None and not any(
+      encoding.MessageToDict(encryption_metadata).values()
+  )
+
+
+def _update_encryption_config(bucket_metadata, resource_args):
+  """Updates the bucket_metadata.encryption field based on resource_args.
+
+  Args:
+    bucket_metadata (messages.Bucket): The bucket metadata to update. The
+      `encryption` field of this object may be modified.
+    resource_args (request_config_factory._BucketConfig): Contains desired
+      changes for the encryption configuration.
+  """
+
+  messages = apis.GetMessagesModule('storage', 'v1')
+  default_encryption_key = resource_args.default_encryption_key
+
+  if default_encryption_key is user_request_args_factory.CLEAR:
+    if bucket_metadata.encryption:
+      bucket_metadata.encryption.defaultKmsKeyName = None
+  elif default_encryption_key is not None:
+    if bucket_metadata.encryption is None:
+      bucket_metadata.encryption = messages.Bucket.EncryptionValue()
+    bucket_metadata.encryption.defaultKmsKeyName = default_encryption_key
+
+  if resource_args.encryption_enforcement_file_path is not None:
+    encryption_enforcement_updates = (
+        metadata_field_converters.process_encryption_enforcement_config(
+            resource_args.encryption_enforcement_file_path
+        )
+    )
+    if encryption_enforcement_updates:
+      if bucket_metadata.encryption is None:
+        bucket_metadata.encryption = encryption_enforcement_updates
+      else:
+        # Merge fields from encryption_updates into existing
+        # bucket_metadata.encryption
+        # Note: Default KMS key is handled separately.
+        for field in _ENCRYPTION_ENFORCEMENT_FIELDS:
+          try:
+            # Check if the field was present in the message.
+            updated_value = encryption_enforcement_updates.get_assigned_value(
+                field
+            )
+          except KeyError:
+            # Field was not present in encryption_enforcement_updates, do not
+            # update.
+            pass
+          else:
+            # If no KeyError, the field was present, so we update it.
+            setattr(bucket_metadata.encryption, field, updated_value)
+  if _should_clear_encryption_field(bucket_metadata.encryption):
+    bucket_metadata.encryption = None
+
+
 def update_bucket_metadata_from_request_config(bucket_metadata, request_config):
   """Sets Apitools Bucket fields based on values in request_config."""
   resource_args = getattr(request_config, 'resource_args', None)
@@ -494,11 +726,10 @@ def update_bucket_metadata_from_request_config(bucket_metadata, request_config):
     )
   if resource_args.cors_file_path is not None:
     bucket_metadata.cors = metadata_field_converters.process_cors(
-        resource_args.cors_file_path)
-  if resource_args.default_encryption_key is not None:
-    bucket_metadata.encryption = (
-        metadata_field_converters.process_default_encryption_key(
-            resource_args.default_encryption_key))
+        resource_args.cors_file_path
+    )
+  _update_encryption_config(bucket_metadata, resource_args)
+
   if resource_args.default_event_based_hold is not None:
     bucket_metadata.defaultEventBasedHold = (
         resource_args.default_event_based_hold)
@@ -611,7 +842,7 @@ def get_cleared_bucket_fields(request_config):
     cleared_fields.append('cors')
 
   if resource_args.default_encryption_key == user_request_args_factory.CLEAR:
-    cleared_fields.append('encryption')
+    cleared_fields.append('encryption.defaultKmsKeyName')
 
   if resource_args.default_storage_class == user_request_args_factory.CLEAR:
     cleared_fields.append('storageClass')
@@ -634,8 +865,7 @@ def get_cleared_bucket_fields(request_config):
   elif resource_args.log_object_prefix == user_request_args_factory.CLEAR:
     cleared_fields.append('logging.logObjectPrefix')
 
-  if resource_args.public_access_prevention == user_request_args_factory.CLEAR:
-    cleared_fields.append('iamConfiguration.publicAccessPrevention')
+  # A cleared public_access_prevention value defaults to 'inherited'.
 
   if resource_args.retention_period == user_request_args_factory.CLEAR:
     cleared_fields.append('retentionPolicy')
@@ -749,11 +979,197 @@ def process_value_or_clear_flag(metadata, key, value):
     setattr(metadata, key, value)
 
 
+def get_contexts_dict_from_custom_contexts_dict(custom_contexts_dict):
+  """Returns contexts dict from custom contexts dict."""
+  return {ContextType.CUSTOM.value.lower(): custom_contexts_dict}
+
+
+def parse_custom_contexts_from_file(file_path):
+  """Parses custom contexts from a file, and validate it against the message.
+
+  Args:
+    file_path (str): Path to the file containing the custom contexts.
+
+  Returns:
+    A dictionary containing the custom contexts parsed from the file.
+
+  Raises:
+    errors.Error: If the provided file doesn't exist or is not a valid
+      json/yaml file.
+  """
+  try:
+    messages = apis.GetMessagesModule('storage', 'v1')
+    parsed_custom_contexts = metadata_util.cached_read_yaml_json_file(
+        file_path
+    )
+
+    # We extract the value from the dict, because user might specify other
+    # fields in the dict which API might not expect, such as 'type' or
+    # 'createTime'.
+    extracted_custom_contexts = {}
+    for key, value in parsed_custom_contexts.items():
+      if (
+          not isinstance(value, dict)
+          or CONTEXT_VALUE_LITERAL not in value
+      ):
+        raise errors.Error('Invalid format for specified contexts file.')
+
+      extracted_custom_contexts[key] = (
+          get_context_value_dict_from_value(
+              value[CONTEXT_VALUE_LITERAL]
+          )
+      )
+
+    # Validate the parsed content respect the API message.
+    encoding_helper.DictToMessage(
+        extracted_custom_contexts, messages.Object.ContextsValue.CustomValue
+    )
+    return extracted_custom_contexts
+  except (errors.InvalidUrlError, AttributeError):
+    raise errors.Error(
+        'Error while parsing the specified contexts file, please ensure that'
+        ' specified file exists and is valid.',
+    )
+
+
+def get_updated_custom_contexts(
+    existing_custom_contexts,
+    request_config,
+    method_type,
+):
+  """Returns a dictionary with updated custom contexts based on a merge strategy.
+
+  Args:
+    existing_custom_contexts (dict): Existing custom contexts for an object.
+    request_config (request_config): May contain custom contexts fields that
+      should be modified.
+    method_type (MethodType): method_type for which the custom contexts are
+      being updated.
+
+  Returns:
+    A dictionary containing the updated custom contexts, or None if no updates
+    are needed.
+  """
+  resource_args = request_config.resource_args
+  if not resource_args or not (
+      resource_args.custom_contexts_to_set
+      or resource_args.custom_contexts_to_remove
+      or resource_args.custom_contexts_to_update
+  ):
+    return (
+        copy.deepcopy(existing_custom_contexts)
+        if method_type != MethodType.OBJECT_PATCH
+        else None
+    )
+
+  if resource_args.custom_contexts_to_set == user_request_args_factory.CLEAR:
+    return {}
+
+  if resource_args.custom_contexts_to_set:
+    if isinstance(resource_args.custom_contexts_to_set, str):
+      # It points to a file, so parse it and update the contexts.
+      parsed_custom_contexts = parse_custom_contexts_from_file(
+          resource_args.custom_contexts_to_set
+      )
+    else:
+      parsed_custom_contexts = {
+          key: get_context_value_dict_from_value(value)
+          for key, value in resource_args.custom_contexts_to_set.items()
+      }
+
+    if method_type != MethodType.OBJECT_PATCH:
+      # 'override' behavior: Just return the new set of contexts
+      return parsed_custom_contexts
+
+    # `patch` behavior: Clear existing contexts before setting new ones
+    updated_custom_contexts = {elem: {} for elem in existing_custom_contexts}
+    updated_custom_contexts.update(**parsed_custom_contexts)
+    return updated_custom_contexts
+
+  updated_custom_contexts = (
+      copy.deepcopy(existing_custom_contexts)
+      if method_type != MethodType.OBJECT_PATCH
+      else {}
+  )
+
+  if resource_args.custom_contexts_to_remove:
+    for key in resource_args.custom_contexts_to_remove:
+      if method_type == MethodType.OBJECT_PATCH:
+        # patch behavior: Remove the specified contexts from the existing
+        # contexts
+        updated_custom_contexts[key] = {}
+      else:
+        # override behavior: Remove the keys from the updated contexts.
+        updated_custom_contexts.pop(key, None)
+
+  if resource_args.custom_contexts_to_update:
+    for key, value in resource_args.custom_contexts_to_update.items():
+      updated_custom_contexts[key] = (
+          get_context_value_dict_from_value(value)
+      )
+
+  return updated_custom_contexts
+
+
+def update_custom_contexts_from_request_config(
+    object_metadata,
+    request_config,
+    method_type=None,
+):
+  """Updates custom contexts in object_metadata based on request_config.
+
+  Args:
+    object_metadata (storage_v1_messages.Object): Existing object metadata.
+    request_config (request_config): May contain custom contexts fields that
+      should be modified.
+    method_type (MethodType): Different API methods have different metadata
+      handling. for example, objects.rewrite handles contexts updates in one
+      way, while objects.patch handles contexts updates in another way. This
+      variable is tune the handling of metadata updates based on the API method.
+      If invalid an error will be thrown, if None, the default handling
+      would be used (object.patch behavior)
+
+  Raises:
+    errors.Error: If the method type is not supported.
+  """
+  if not object_metadata.contexts or not object_metadata.contexts.custom:
+    existing_custom_contexts = {}
+  else:
+    existing_custom_contexts = encoding_helper.MessageToDict(
+        object_metadata.contexts.custom
+    )
+
+  if not method_type:
+    method_type = MethodType.OBJECT_PATCH
+  elif not isinstance(method_type, MethodType):
+    raise errors.Error(
+        'Unsupported method type for updating custom contexts: {}.'.format(
+            method_type
+        )
+    )
+
+  messages = apis.GetMessagesModule('storage', 'v1')
+  custom_contexts_dict = get_updated_custom_contexts(
+      existing_custom_contexts, request_config, method_type
+  )
+  if method_type != MethodType.OBJECT_PATCH and not custom_contexts_dict:
+    custom_contexts_dict = None
+
+  if custom_contexts_dict is not None:
+    object_metadata.contexts = encoding_helper.DictToMessage(
+        get_contexts_dict_from_custom_contexts_dict(custom_contexts_dict),
+        messages.Object.ContextsValue,
+    )
+  else:
+    object_metadata.contexts = None
+
+
 def update_object_metadata_from_request_config(
     object_metadata,
     request_config,
     attributes_resource=None,
     posix_to_set=None,
+    method_type=None,
 ):
   """Sets Apitools Object fields based on values in request_config.
 
@@ -768,6 +1184,15 @@ def update_object_metadata_from_request_config(
       --preserve_symlink flags. This value is ignored unless it is an instance
       of FileObjectResource.
     posix_to_set (PosixAttributes|None): Set as custom metadata on target.
+    method_type (MethodType|None): Different API methods have different metadata
+      handling, for example, objects.rewrite handles contexts updates in one
+      way, while objects.patch handles contexts updates in another way. This
+      variable is tune the handling of metadata updates based on the API method.
+      If invalid, an error will be thrown. If None, the default handling
+      would be used for each metadata field.
+
+  Raises:
+    errors.Error: If the method type is not supported.
   """
   resource_args = request_config.resource_args
 
@@ -789,6 +1214,11 @@ def update_object_metadata_from_request_config(
     object_metadata.metadata = encoding_helper.DictToMessage(
         custom_fields_dict, messages.Object.MetadataValue)
 
+  # Custom contexts handling.
+  update_custom_contexts_from_request_config(
+      object_metadata, request_config, method_type
+  )
+
   should_gzip_locally = get_should_gzip_locally(
       attributes_resource, request_config)
 
