@@ -28,9 +28,6 @@ def AddFlagName(parser):
   )
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import argparse
 import datetime
@@ -660,7 +657,26 @@ def AddCPUCount(parser, required):
       '--cpu-count',
       required=required,
       type=int,
-      choices=[1, 2, 4, 8, 16, 32, 48, 64, 72, 96, 128],
+      choices=[
+          1,
+          2,
+          4,
+          8,
+          14,
+          16,
+          22,
+          32,
+          44,
+          48,
+          64,
+          72,
+          88,
+          96,
+          128,
+          144,
+          192,
+          288,
+      ],
       help=(
           'Whole number value indicating how many vCPUs the machine should'
           ' contain. If the instance does not have a machine-type, the vCPU'
@@ -737,6 +753,11 @@ def AddMachineType(parser, required=False):
       'z3-highmem-22-standardlssd',
       'z3-highmem-44-standardlssd',
       'z3-highmem-88-standardlssd',
+      'z3-highmem-8-highlssd',
+      'z3-highmem-16-highlssd',
+      'z3-highmem-22-highlssd',
+      'z3-highmem-32-highlssd',
+      'z3-highmem-44-highlssd',
   ]
   parser.add_argument(
       '--machine-type',
@@ -1759,24 +1780,20 @@ def AddRequireConnectors(parser):
   )
 
 
-def AddDatabaseVersion(parser, alloydb_messages, release_track):
+def AddDatabaseVersion(parser, alloydb_messages):
   """Adds Database Version flag.
 
   Args:
     parser: argparse.Parser: Parser object for command line inputs.
     alloydb_messages: Message module.
-    release_track: The command version being used - GA/BETA/ALPHA.
   """
   choices = [
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_14,
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_15,
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_16,
       alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_17,
+      alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_18,
   ]
-  if release_track in (base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA):
-    choices.append(
-        alloydb_messages.Cluster.DatabaseVersionValueValuesEnum.POSTGRES_18
-    )
   parser.add_argument(
       '--database-version',
       required=False,
@@ -1786,7 +1803,7 @@ def AddDatabaseVersion(parser, alloydb_messages, release_track):
   )
 
 
-def AddVersion(parser, alloydb_messages):
+def AddVersion(parser, alloydb_messages) -> None:
   """Adds Version flag.
 
   Args:
@@ -1798,6 +1815,7 @@ def AddVersion(parser, alloydb_messages):
       alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_15,
       alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_16,
       alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_17,
+      alloydb_messages.UpgradeClusterRequest.VersionValueValuesEnum.POSTGRES_18,
   ]
   parser.add_argument(
       '--version',
@@ -1928,7 +1946,6 @@ def AddMaintenanceVersion(parser):
       '--maintenance-version',
       required=False,
       type=str,
-      hidden=True,
       help=(
           'Maintenance version to update the cluster to. Use `latest` to'
           ' apply the latest available maintenance version.'
@@ -2418,3 +2435,128 @@ def AddMigrateCloudSqlFlags(parser: argparse.PARSER) -> None:
           ' backup ID (myBackup).'
       ),
   )
+
+
+def _AddAutoscalerFlags(group):
+  """Add Autoscaler specific flags to the group."""
+  group.add_argument(
+      '--enable-autoscaler',
+      required=False,
+      action=arg_parsers.StoreTrueFalseAction,
+      help='Enable autoscaler for the instance.',
+  )
+
+  group.add_argument(
+      '--autoscaler-max-node-count',
+      required=False,
+      type=arg_parsers.BoundedInt(lower_bound=1, upper_bound=20),
+      default=None,
+      help='Maximum node count for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-cool-down-period-seconds',
+      required=False,
+      type=arg_parsers.Duration(parsed_unit='s'),
+      default=None,
+      help='Cool down period in seconds for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-target-cpu-usage',
+      required=False,
+      type=arg_parsers.BoundedFloat(lower_bound=0, upper_bound=1),
+      default=None,
+      help='Target CPU usage for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-set-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to create or update for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-cron-exp',
+      required=False,
+      type=str,
+      default=None,
+      help='Cron expression for the autoscaler schedule.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-duration-seconds',
+      required=False,
+      type=arg_parsers.Duration(parsed_unit='s'),
+      default=None,
+      help='Duration for which the autoscaler schedule is active in seconds.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-time-zone',
+      required=False,
+      type=str,
+      default=None,
+      help='Time zone for the autoscaler schedule.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-min-node-count',
+      required=False,
+      type=int,
+      default=None,
+      help='Minimum node count for the autoscaler schedule.',
+  )
+
+  group.add_argument(
+      '--autoscaler-schedule-description',
+      required=False,
+      type=str,
+      default=None,
+      help='Description for the autoscaler schedule.',
+  )
+
+
+def AddAutoscalerCreateFlags(parser):
+  """Add Autoscaler specific flags for create command.
+
+  Args:
+    parser: argparse.Parser: Parser object for command line inputs.
+  """
+  group = parser.add_group(help='Autoscaler flags.', hidden=True)
+  _AddAutoscalerFlags(group)
+
+
+def AddAutoscalerUpdateFlags(parser):
+  """Add Autoscaler specific flags for update command.
+
+  Args:
+    parser: argparse.Parser: Parser object for command line inputs.
+  """
+  group = parser.add_group(help='Autoscaler flags.', hidden=True)
+  _AddAutoscalerFlags(group)
+  group.add_argument(
+      '--autoscaler-delete-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to delete for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-disable-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to disable for the autoscaler.',
+  )
+
+  group.add_argument(
+      '--autoscaler-enable-schedule',
+      required=False,
+      type=str,
+      default=None,
+      help='The name of the schedule to enable for the autoscaler.',
+  )
