@@ -15,6 +15,8 @@
 """Utilities for parsing the cloud deploy resource to yaml definition."""
 
 
+from __future__ import annotations
+
 import collections
 import dataclasses
 import datetime
@@ -45,7 +47,7 @@ ADVANCE_ROLLOUT_FIELD = 'advanceRollout'
 PROMOTE_RELEASE_FIELD = 'promoteRelease'
 REPAIR_ROLLOUT_FIELD = 'repairRollout'
 WAIT_FIELD = 'wait'
-LABELS_FIELD = 'labels'
+labels_field = 'labels'
 ANNOTATIONS_FIELD = 'annotations'
 SELECTOR_FIELD = 'selector'
 RULES_FIELD = 'rules'
@@ -60,7 +62,7 @@ PHASES_FIELD = 'phases'
 DESTINATION_PHASE_FIELD = 'destinationPhase'
 DISABLE_ROLLBACK_IF_ROLLOUT_PENDING = 'disableRollbackIfRolloutPending'
 TARGET_FIELD = 'target'
-METADATA_FIELDS = [ANNOTATIONS_FIELD, LABELS_FIELD, NAME_FIELD]
+METADATA_FIELDS = [ANNOTATIONS_FIELD, labels_field, NAME_FIELD]
 EXCLUDE_FIELDS = [
     'createTime',
     'customTargetTypeId',
@@ -77,7 +79,15 @@ REPAIR_PHASES_FIELD = 'repairPhases'
 BACKOFF_MODE_FIELD = 'backoffMode'
 SCHEDULE_FIELD = 'schedule'
 TIME_ZONE_FIELD = 'timeZone'
-LABELS_FIELD = 'labels'
+labels_field = 'labels'
+DEPLOYMENT_OPTIONS_FIELD = 'deploymentOptions'
+KUBERNETES_FIELD = 'kubernetes'
+CLOUD_RUN_FIELD = 'cloudRun'
+NAMESPACE_FIELD = 'namespace'
+KUBECTL_FIELD = 'kubectl'
+FLAGS_FIELD = 'flags'
+KUBERNETES_NAMESPACE_FIELD = 'kubernetesNamespace'
+APPLY_FLAGS_FIELD = 'applyFlags'
 
 
 @enum.unique
@@ -102,6 +112,16 @@ class _TransformContext:
   field: str
 
 
+@enum.unique
+class TaskType(enum.Enum):
+  """The type of task to perform."""
+
+  CONTAINER = 'container'
+
+  def __str__(self):
+    return self.value
+
+
 def ParseDeployConfig(
     messages: list[Any], manifests: list[dict[str, Any]], region: str
 ) -> dict[ResourceKind, list[Any]]:
@@ -191,7 +211,7 @@ def _RemoveApiVersionAndKind(
     value: dict[str, Any], transform_context: _TransformContext
 ) -> None:
   """Removes the apiVersion and kind fields from the manifest."""
-  del value
+  del value  # Unused by _RemoveApiVersionAndKind().
   del transform_context.manifest['apiVersion']
   del transform_context.manifest['kind']
 
@@ -202,7 +222,7 @@ def _MetadataYamlToProto(
   """Moves the fields in metadata to the top level of the manifest."""
   manifest = transform_context.manifest
   manifest[ANNOTATIONS_FIELD] = metadata.get(ANNOTATIONS_FIELD)
-  manifest[LABELS_FIELD] = metadata.get(LABELS_FIELD)
+  manifest[labels_field] = metadata.get(labels_field)
   # I think allowing description in metadata was an accident, not intentional...
   # It's supposed to be a top level field. But even some of our own tests do
   # this, so I think we have to assume customers might have too.
@@ -231,7 +251,7 @@ def _ConvertLabelsToSnakeCase(
     labels: dict[str, str], transform_context: _TransformContext
 ) -> dict[str, str]:
   """Convert labels from camelCase to snake_case."""
-  del transform_context
+  del transform_context  # Unused by _ConvertLabelsToSnakeCase().
   # See go/unified-cloud-labels-proposal.
   return {resource_property.ConvertToSnakeCase(k): v for k, v in labels.items()}
 
@@ -250,7 +270,7 @@ def _RenameOldAutomationRules(
     rule: dict[str, Any], transform_context: _TransformContext
 ) -> dict[str, Any]:
   """Renames the old automation rule fields to the new format."""
-  del transform_context
+  del transform_context  # Unused by _RenameOldAutomationRules().
   if PROMOTE_RELEASE_FIELD in rule:
     rule[PROMOTE_RELEASE_RULE_FIELD] = rule[PROMOTE_RELEASE_FIELD]
     del rule[PROMOTE_RELEASE_FIELD]
@@ -283,7 +303,7 @@ def _AddEmptyRepairAutomationRetryMessage(
     repair_phase: dict[str, Any], transform_context: _TransformContext
 ) -> dict[str, Any]:
   """Add an empty retry field if it's defined in the manifest but set to None."""
-  del transform_context
+  del transform_context  # Unused by _AddEmptyRepairAutomationRetryMessage().
   if RETRY_FIELD in repair_phase and repair_phase[RETRY_FIELD] is None:
     repair_phase[RETRY_FIELD] = {}
   return repair_phase
@@ -293,7 +313,7 @@ def _ConvertRepairAutomationBackoffModeEnumValuesToProtoFormat(
     value: str, transform_context
 ) -> str:
   """Converts the backoffMode values to the proto enum names."""
-  del transform_context
+  del transform_context  # Unused by this function.
 
   if not value.startswith('BACKOFF_MODE_'):
     return 'BACKOFF_MODE_' + value
@@ -303,7 +323,7 @@ def _ConvertAutomationWaitMinToSec(
     wait: str, transform_context: _TransformContext
 ) -> str:
   """Converts the wait time from (for example) "5m" to "300s"."""
-  del transform_context
+  del transform_context  # Unused by _ConvertAutomationWaitMinToSec().
   if not re.fullmatch(r'\d+m', wait):
     raise exceptions.AutomationWaitFormatError()
   mins = wait[:-1]
@@ -435,6 +455,104 @@ def _ReplaceCustomTargetType(
   ).RelativeName()
 
 
+def _ConvertStageDeploymentOptions(
+    stage: dict[str, Any],
+    transform_context: _TransformContext,
+) -> dict[str, Any]:
+  """Converts deployment options in stage to proto format."""
+  if KUBERNETES_FIELD in stage and CLOUD_RUN_FIELD in stage:
+    raise exceptions.CloudDeployConfigError.for_resource_field(
+        transform_context.kind,
+        transform_context.name,
+        transform_context.field,
+        f'{KUBERNETES_FIELD} and {CLOUD_RUN_FIELD} cannot be set at the same'
+        ' time',
+    )
+  if KUBERNETES_FIELD in stage:
+    k8s = stage[KUBERNETES_FIELD]
+    if not isinstance(k8s, dict):
+      raise exceptions.CloudDeployConfigError.for_resource_field(
+          transform_context.kind,
+          transform_context.name,
+          transform_context.field,
+          f'{KUBERNETES_FIELD} must be a dictionary',
+      )
+    if NAMESPACE_FIELD in k8s:
+      k8s[KUBERNETES_NAMESPACE_FIELD] = k8s.pop(NAMESPACE_FIELD)
+    if FLAGS_FIELD in k8s.get(KUBECTL_FIELD, {}):
+      k8s[KUBECTL_FIELD][APPLY_FLAGS_FIELD] = k8s[KUBECTL_FIELD].pop(
+          FLAGS_FIELD
+      )
+    stage.setdefault(DEPLOYMENT_OPTIONS_FIELD, {})[KUBERNETES_FIELD] = k8s
+    del stage[KUBERNETES_FIELD]
+
+  if CLOUD_RUN_FIELD in stage:
+    cr = stage[CLOUD_RUN_FIELD]
+    if not isinstance(cr, dict):
+      raise exceptions.CloudDeployConfigError.for_resource_field(
+          transform_context.kind,
+          transform_context.name,
+          transform_context.field,
+          f'{CLOUD_RUN_FIELD} must be a dictionary',
+      )
+    stage.setdefault(DEPLOYMENT_OPTIONS_FIELD, {})[CLOUD_RUN_FIELD] = cr
+    del stage[CLOUD_RUN_FIELD]
+  return stage
+
+
+def _ConvertYamlTaskToProto(
+    task: dict[str, Any], transform_context: _TransformContext
+) -> dict[str, Any]:
+  """Transforms a task in YAML format to proto-compatible format."""
+  # Schema validation verifies the presence of the 'type' key so we
+  # can just grab the value without supplying a default value.
+  task_type = task['type']
+  if task_type == TaskType.CONTAINER.value:
+    new_task = {}
+    container_task = {}
+    for k, v in task.items():
+      if k != 'type':
+        container_task[k] = v
+    new_task[TaskType.CONTAINER.value] = container_task
+    return new_task
+  raise exceptions.CloudDeployConfigError.for_resource_field(
+      transform_context.kind,
+      transform_context.name,
+      transform_context.field,
+      f'unsupported task type: {task_type}',
+  )
+
+
+def _ConvertYamlVerifyConfigToProto(
+    strategy: dict[str, Any], transform_context: _TransformContext
+) -> dict[str, Any]:
+  """Transforms a verifyConfig in YAML format to proto-compatible format."""
+  verify = strategy.get('verify', None)
+  if isinstance(verify, dict):
+    if 'verifyConfig' in strategy:
+      raise exceptions.CloudDeployConfigError.for_resource_field(
+          transform_context.kind,
+          transform_context.name,
+          transform_context.field,
+          'verify and verifyConfig cannot be set at the same time',
+      )
+    strategy['verifyConfig'] = verify
+    del strategy['verify']
+  return strategy
+
+
+def _ConvertProtoVerifyConfigToYaml(
+    strategy: dict[str, Any], transform_context: _TransformContext
+) -> dict[str, Any]:
+  """Transforms a verifyConfig in YAML format to proto-compatible format."""
+  del transform_context
+  if 'verifyConfig' not in strategy:
+    return strategy
+  strategy['verify'] = strategy['verifyConfig']
+  del strategy['verifyConfig']
+  return strategy
+
+
 @dataclasses.dataclass
 class TransformConfig:
   """Represents a field that needs transformation during parsing.
@@ -570,6 +688,46 @@ _PARSE_TRANSFORMS = [
         replace=_ReplaceCustomTargetType,
         schema={'type': 'string'},
     ),
+    TransformConfig(
+        kinds=[ResourceKind.DELIVERY_PIPELINE],
+        fields=['serialPipeline.stages[]'],
+        replace=_ConvertStageDeploymentOptions,
+    ),
+    TransformConfig(
+        kinds=[ResourceKind.DELIVERY_PIPELINE],
+        fields=[
+            'serialPipeline.stages[].strategy.standard',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[]',
+        ],
+        replace=_ConvertYamlVerifyConfigToProto,
+    ),
+    TransformConfig(
+        kinds=[ResourceKind.DELIVERY_PIPELINE, ResourceKind.CUSTOM_TARGET_TYPE],
+        fields=[
+            'serialPipeline.stages[].strategy.standard.predeploy.tasks[]',
+            'serialPipeline.stages[].strategy.standard.postdeploy.tasks[]',
+            'serialPipeline.stages[].strategy.standard.verifyConfig.tasks[]',
+            'serialPipeline.stages[].strategy.standard.analysis.customChecks[].task',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.predeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.postdeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.verifyConfig.tasks[]',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.analysis.customChecks[].task',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].predeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].postdeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].verifyConfig.tasks[]',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].analysis.customChecks[].task',
+            'tasks.render',
+            'tasks.deploy',
+        ],
+        replace=_ConvertYamlTaskToProto,
+        schema={
+            'type': 'object',
+            'properties': {'type': {'type': 'string'}},
+            'required': ['type'],
+            'additionalProperties': True,
+        },
+    ),
 ]
 
 
@@ -643,14 +801,14 @@ def AddApiVersionAndKind(
     value: Any, transform_context: _TransformContext
 ) -> None:
   """Adds the API version and kind to the manifest."""
-  del value
+  del value  # Unused by AddApiVersionAndKind.
   transform_context.manifest['apiVersion'] = API_VERSION_V1
   transform_context.manifest['kind'] = transform_context.kind.value
 
 
 def _RemoveField(value: Any, transform_context: _TransformContext) -> None:
   """Removes the field from the manifest."""
-  del value
+  del value  # Unused by _RemoveField.
   del transform_context.manifest[transform_context.field]
 
 
@@ -658,7 +816,7 @@ def _MetadataProtoToYaml(
     value: Any, transform_context: _TransformContext
 ) -> None:
   """Converts the metadata proto to YAML."""
-  del value
+  del value  # Unused by _MetadataProtoToYaml.
   transform_context.manifest['metadata'] = {}
   for k in METADATA_FIELDS:
     if k in transform_context.manifest:
@@ -670,7 +828,7 @@ def _MetadataProtoToYaml(
 def _ConvertAutomationWaitSecToMin(
     wait: str, transform_context: _TransformContext
 ) -> str:
-  del transform_context
+  del transform_context  # Unused by _ConvertAutomationWaitSecToMin.
   if not wait:
     return wait
   seconds = wait[:-1]
@@ -679,6 +837,21 @@ def _ConvertAutomationWaitSecToMin(
   return '%sm' % mins
 
 
+def _ConvertProtoTaskToYaml(
+    task: dict[str, Any], transform_context: _TransformContext
+) -> dict[str, Any]:
+  """Converts a proto task to YAML format suitable for export."""
+  del transform_context  # Unused by _ConvertProtoTaskToYaml.
+  new_task = {}
+  for task_type in TaskType:
+    if task.get(task_type.value) is not None:
+      new_task['type'] = task_type.value
+      task_data = task[task_type.value]
+      for k, v in task_data.items():
+        new_task[k] = v
+  return new_task
+
+
 def ConvertPolicyOneTimeWindowToYamlFormat(
     one_time_window: dict[str, Any], transform_context: _TransformContext
 ) -> dict[str, Any]:
@@ -717,7 +890,7 @@ def ConvertTimeProtoToString(
     time_obj: dict[str, str], transform_context: _TransformContext
 ) -> str:
   """Converts a time object to a string."""
-  del transform_context
+  del transform_context  # Unused by ConvertTimeProtoToString.
   hours = time_obj.get('hours') or 0
   minutes = time_obj.get('minutes') or 0
   time_str = f'{hours:02}:{minutes:02}'
@@ -808,6 +981,35 @@ _EXPORT_TRANSFORMS = [
         ],
         replace=ConvertTimeProtoToString,
     ),
+    TransformConfig(
+        kinds=[ResourceKind.DELIVERY_PIPELINE, ResourceKind.CUSTOM_TARGET_TYPE],
+        fields=[
+            'serialPipeline.stages[].strategy.standard.predeploy.tasks[]',
+            'serialPipeline.stages[].strategy.standard.postdeploy.tasks[]',
+            'serialPipeline.stages[].strategy.standard.verifyConfig.tasks[]',
+            'serialPipeline.stages[].strategy.standard.analysis.customChecks[].task',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.predeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.postdeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.verifyConfig.tasks[]',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment.analysis.customChecks[].task',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].predeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].postdeploy.tasks[]',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].verifyConfig.tasks[]',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[].analysis.customChecks[].task',
+            'tasks.render',
+            'tasks.deploy',
+        ],
+        replace=_ConvertProtoTaskToYaml,
+    ),
+    TransformConfig(
+        kinds=[ResourceKind.DELIVERY_PIPELINE],
+        fields=[
+            'serialPipeline.stages[].strategy.standard',
+            'serialPipeline.stages[].strategy.canary.canaryDeployment',
+            'serialPipeline.stages[].strategy.canary.customCanaryDeployment.phaseConfigs[]',
+        ],
+        replace=_ConvertProtoVerifyConfigToYaml,
+    ),
 ]
 
 
