@@ -14,11 +14,7 @@
 # limitations under the License.
 """Class for representing various changes to a Configuration."""
 
-from __future__ import absolute_import
 from __future__ import annotations
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import abc
 import argparse
@@ -1787,6 +1783,21 @@ class JobMaxRetriesChange(TemplateConfigChanger):
     return resource
 
 
+@dataclasses.dataclass(frozen=True)
+class DelayExecutionChange(TemplateConfigChanger):
+  """Represents the intent to update the job's delay execution setting.
+
+  Attributes:
+    delay_execution: True if the triggered execution can be delayed.
+  """
+
+  delay_execution: bool
+
+  def Adjust(self, resource):
+    resource.execution_template.spec.delayExecution = self.delay_execution
+    return resource
+
+
 @dataclasses.dataclass(frozen=True)
 class JobTaskTimeoutChange(TemplateConfigChanger):
   """Represents the user intent to update a job's instance deadline.
