@@ -15,9 +15,6 @@
 """The command lists the deployment configurations of a given model supported by Model Garden."""
 
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.ai.model_garden import client as client_mg
@@ -26,7 +23,11 @@ from googlecloudsdk.calliope import exceptions as c_exceptions
 from googlecloudsdk.command_lib.ai import constants
 from googlecloudsdk.command_lib.ai import endpoint_util
 from googlecloudsdk.command_lib.ai import validation
+from googlecloudsdk.command_lib.ai.region_util import (
+    _IsDefaultUniverse,
+)
 from googlecloudsdk.core import exceptions as core_exceptions
+from googlecloudsdk.core import properties
 
 
 _DEFAULT_FORMAT = """
@@ -141,7 +142,14 @@ class ListDeployMentConfig(base.ListCommand):
     validation.ValidateModelGardenModelArgs(args)
     version = constants.BETA_VERSION
 
-    with endpoint_util.AiplatformEndpointOverrides(
-        version, region='us-central1'
-    ):
+    if _IsDefaultUniverse():
+      api_region = 'us-central1'
+    else:
+      api_region = properties.VALUES.ai.region.Get()
+      if not api_region:
+        raise c_exceptions.RequiredArgumentException(
+            'ai/region',
+            'The [ai/region] property must be set in this environment.',
+        )
+    with endpoint_util.AiplatformEndpointOverrides(version, region=api_region):
       return self._GetMultiDeploy(args, version)
