@@ -15,9 +15,6 @@
 
 """A command that prints access tokens."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import textwrap
 import time
