@@ -14,14 +14,11 @@
 # limitations under the License.
 """Command group for Backup and DR Backup Plan Revisions."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
 
 @base.DefaultUniverseOnly
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.GA)
 class BackupPlanRevisions(base.Group):
   """View Backup and DR backup plan revisions."""
