@@ -15,9 +15,6 @@
 """Restores a Compute Disk Backup."""
 
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.backupdr import util
@@ -78,6 +75,7 @@ class Disk(base.Command):
     disk_flags.AddConfidentialComputeArg(parser, False)
     disk_flags.AddResourcePoliciesArg(parser, False)
     disk_flags.AddKmsKeyArg(parser, False)
+    disk_flags.AddClearEncryptionKeyArg(parser)
 
   def _ParseResourcePolicies(self, resource_policies, project, zone):
     """Parses the resource policies flag."""
@@ -143,6 +141,13 @@ class Disk(base.Command):
       restore_config['ResourcePolicies'] = self._ParseResourcePolicies(
           args.resource_policies, args.target_project, args.target_zone
       )
+    if (
+        hasattr(args, 'clear_encryption_key')
+        and args.clear_encryption_key
+    ):
+      restore_config['ClearOverridesFieldMask'] = (
+          'disk_restore_properties.disk_encryption_key'
+      )
     try:
       operation = client.RestoreDisk(backup, restore_config)
     except apitools_exceptions.HttpError as e:
