@@ -14,14 +14,13 @@
 # limitations under the License.
 """Commands for reading and manipulating images."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
 
 @base.UniverseCompatible
+@base.ReleaseTracks(
+    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class Images(base.Group):
   """List, create, and delete Compute Engine images."""
 
