@@ -14,9 +14,6 @@
 # limitations under the License.
 """Command for creating instances."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import filter_rewrite
@@ -161,6 +158,9 @@ class Create(base.Command):
   _support_flex_start = False
   _support_source_snapshot_region = False
   _support_skip_guest_os_shutdown = True
+  _support_preemption_notice_duration = False
+  _support_instance_flexibility_policy = True
+  _support_workload_identity_config = False
 
   _log_async = False
 
@@ -179,6 +179,9 @@ class Create(base.Command):
         support_flex_start=cls._support_flex_start,
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
+        support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_instance_flexibility_policy=cls._support_instance_flexibility_policy,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
     cls.AddSourceInstanceTemplate(parser)
 
@@ -221,6 +224,9 @@ class Create(base.Command):
         self._support_graceful_shutdown,
         self._support_source_snapshot_region,
         self._support_skip_guest_os_shutdown,
+        self._support_preemption_notice_duration,
+        self._support_instance_flexibility_policy,
+        self._support_workload_identity_config,
     )
     bulk_instance_resource = bulk_util.CreateBulkInsertInstanceResource(
         args,
@@ -269,6 +275,7 @@ class Create(base.Command):
         args,
         support_max_count_per_zone=self._support_max_count_per_zone,
         support_custom_hostnames=self._support_custom_hostnames,
+        support_instance_flexibility_policy=self._support_instance_flexibility_policy,
     )
 
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
@@ -365,6 +372,9 @@ class CreateBeta(Create):
   _support_igmp_query = False
   _support_source_snapshot_region = False
   _support_skip_guest_os_shutdown = True
+  _support_preemption_notice_duration = False
+  _support_instance_flexibility_policy = True
+  _support_workload_identity_config = False
 
   @classmethod
   def Args(cls, parser):
@@ -383,6 +393,9 @@ class CreateBeta(Create):
         support_igmp_query=cls._support_igmp_query,
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
+        support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_instance_flexibility_policy=cls._support_instance_flexibility_policy,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
     cls.AddSourceInstanceTemplate(parser)
 
@@ -409,6 +422,9 @@ class CreateAlpha(Create):
   _support_flex_start = False
   _support_source_snapshot_region = True
   _support_skip_guest_os_shutdown = True
+  _support_preemption_notice_duration = True
+  _support_instance_flexibility_policy = True
+  _support_workload_identity_config = True
 
   @classmethod
   def Args(cls, parser):
@@ -427,6 +443,9 @@ class CreateAlpha(Create):
         support_flex_start=cls._support_flex_start,
         support_source_snapshot_region=cls._support_source_snapshot_region,
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
+        support_preemption_notice_duration=cls._support_preemption_notice_duration,
+        support_instance_flexibility_policy=cls._support_instance_flexibility_policy,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
 
     cls.AddSourceInstanceTemplate(parser)
