@@ -14,9 +14,6 @@
 # limitations under the License.
 """Command for creating instances."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import re
 
@@ -124,6 +121,8 @@ def _CommonArgs(
     support_skip_guest_os_shutdown=False,
     support_preemption_notice_duration=False,
     support_enable_vpc_scoped_dns=False,
+    support_service_class_id=False,
+    support_workload_identity_config=False,
 ):
   """Register parser args common to all tracks."""
   metadata_utils.AddMetadataArgs(parser)
@@ -153,6 +152,7 @@ def _CommonArgs(
       support_ipv6_only=support_ipv6_only,
       support_igmp_query=support_igmp_query,
       support_enable_vpc_scoped_dns=support_enable_vpc_scoped_dns,
+      support_service_class_id=support_service_class_id,
   )
   instances_flags.AddAcceleratorArgs(parser)
   instances_flags.AddMachineTypeArgs(parser)
@@ -276,6 +276,8 @@ def _CommonArgs(
   instances_flags.AddTurboModeArgs(parser)
   if support_skip_guest_os_shutdown:
     instances_flags.AddSkipGuestOsShutdownArgs(parser)
+  if support_workload_identity_config:
+    instances_flags.AddWorkloadIdentityConfigArgs(parser)
   instances_flags.AddRequestValidForDurationArgs(parser)
 
 
@@ -332,6 +334,8 @@ class Create(base.CreateCommand):
   _support_skip_guest_os_shutdown = True
   _support_preemption_notice_duration = False
   _support_enable_vpc_scoped_dns = False
+  _support_service_class_id = False
+  _support_workload_identity_config = False
 
   @classmethod
   def Args(cls, parser):
@@ -362,6 +366,7 @@ class Create(base.CreateCommand):
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
         support_preemption_notice_duration=cls._support_preemption_notice_duration,
         support_enable_vpc_scoped_dns=cls._support_enable_vpc_scoped_dns,
+        support_service_class_id=cls._support_service_class_id,
     )
     cls.SOURCE_INSTANCE_TEMPLATE = (
         instances_flags.MakeSourceInstanceTemplateArg()
@@ -456,6 +461,7 @@ class Create(base.CreateCommand):
         support_ipv6_assignment=self._support_ipv6_assignment,
         support_internal_ipv6_reservation=self._support_internal_ipv6_reservation,
         support_enable_vpc_scoped_dns=self._support_enable_vpc_scoped_dns,
+        support_service_class_id=self._support_service_class_id,
     )
 
     confidential_vm_type = instance_utils.GetConfidentialVmType(
@@ -493,6 +499,13 @@ class Create(base.CreateCommand):
 
     project_to_sa = create_utils.GetProjectToServiceAccountMap(
         args, instance_refs, compute_client, skip_defaults)
+    workload_identity_config = (
+        instance_utils.CreateWorkloadIdentityConfigMessage(
+            args,
+            compute_client.messages,
+            self._support_workload_identity_config,
+        )
+    )
 
     requests = []
     for instance_ref in instance_refs:
@@ -564,7 +577,11 @@ class Create(base.CreateCommand):
           networkInterfaces=network_interfaces,
           serviceAccounts=project_to_sa[instance_ref.project],
           scheduling=scheduling,
-          tags=tags)
+          tags=tags,
+      )
+
+      if self._support_workload_identity_config and workload_identity_config:
+        instance.workloadIdentityConfig = workload_identity_config
 
       if self._support_partner_metadata and (
           args.partner_metadata or args.partner_metadata_from_file
@@ -853,6 +870,8 @@ class CreateBeta(Create):
   _support_skip_guest_os_shutdown = True
   _support_preemption_notice_duration = False
   _support_enable_vpc_scoped_dns = False
+  _support_service_class_id = False
+  _support_workload_identity_config = False
 
   def GetSourceMachineImage(self, args, resources):
     """Retrieves the specified source machine image's selflink.
@@ -899,6 +918,8 @@ class CreateBeta(Create):
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
         support_preemption_notice_duration=cls._support_preemption_notice_duration,
         support_enable_vpc_scoped_dns=cls._support_enable_vpc_scoped_dns,
+        support_service_class_id=cls._support_service_class_id,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
     cls.SOURCE_INSTANCE_TEMPLATE = (
         instances_flags.MakeSourceInstanceTemplateArg()
@@ -979,6 +1000,8 @@ class CreateAlpha(CreateBeta):
   _support_skip_guest_os_shutdown = True
   _support_preemption_notice_duration = True
   _support_enable_vpc_scoped_dns = True
+  _support_service_class_id = True
+  _support_workload_identity_config = True
 
   @classmethod
   def Args(cls, parser):
@@ -1013,6 +1036,8 @@ class CreateAlpha(CreateBeta):
         support_skip_guest_os_shutdown=cls._support_skip_guest_os_shutdown,
         support_preemption_notice_duration=cls._support_preemption_notice_duration,
         support_enable_vpc_scoped_dns=cls._support_enable_vpc_scoped_dns,
+        support_service_class_id=cls._support_service_class_id,
+        support_workload_identity_config=cls._support_workload_identity_config,
     )
 
     CreateAlpha.SOURCE_INSTANCE_TEMPLATE = (
