@@ -14,9 +14,6 @@
 # limitations under the License.
 """Command for listing interconnect attachments."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import filter_rewrite
@@ -69,8 +66,9 @@ class List(base.ListCommand):
     args.filter, filter_expr = filter_rewrite.Rewriter().Rewrite(
         args.filter, defaults=defaults)
     request = messages.ComputeInterconnectAttachmentsAggregatedListRequest(
-        project=project, filter=filter_expr,
-        returnPartialSuccess=True)
+        project=project, filter=filter_expr)
+    if hasattr(request, 'returnPartialSuccess'):
+      request.returnPartialSuccess = True
 
     # TODO(b/34871930): Write and use helper for handling listing.
     interconnect_attachments_lists, next_page_token = self._GetListPage(
