@@ -14,9 +14,6 @@
 # limitations under the License.
 """Command for getting effective firewalls of GCP networks."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import firewalls_utils
@@ -82,6 +79,7 @@ class GetEffectiveFirewalls(base.DescribeCommand, base.ListCommand):
       )
 
     if hasattr(res, 'firewallPolicys') and res.firewallPolicys:
+      all_unsorted_firewall_policy = []
       for fp in res.firewallPolicys:
         firewall_policy_rule = firewalls_utils.SortFirewallPolicyRules(
             client, fp.rules
@@ -94,9 +92,13 @@ class GetEffectiveFirewalls(base.DescribeCommand, base.ListCommand):
             rules=firewall_policy_rule,
             packetMirroringRules=packet_mirroring_rule,
             type=fp.type,
+            priority=fp.priority,
         )
 
-        all_firewall_policy.append(fp_response)
+        all_unsorted_firewall_policy.append(fp_response)
+      all_firewall_policy = firewalls_utils.SortFirewallPolicies(
+          client, all_unsorted_firewall_policy
+      )
     elif hasattr(res, 'organizationFirewalls'):
       for sp in res.organizationFirewalls:
         org_firewall_rule = firewalls_utils.SortOrgFirewallRules(
