@@ -15,9 +15,6 @@
 
 """Command for listing subnetworks."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.api_lib.compute import lister
@@ -85,12 +82,19 @@ class List(base.ListCommand):
     request_data = lister.ParseMultiScopeFlags(args, holder.resources)
 
     if self._include_view:
+      if args.regions:
+        request_message = client.messages.ComputeSubnetworksListRequest
+      else:
+        request_message = (
+            client.messages.ComputeSubnetworksAggregatedListRequest
+        )
+
       list_implementation = lister.MultiScopeLister(
           client=client,
           regional_service=client.apitools_client.subnetworks,
           aggregation_service=client.apitools_client.subnetworks,
           subnetwork_views_flag=self._GetSubnetworkViews(
-              args.view, client.messages.ComputeSubnetworksListRequest
+              args.view, request_message
           ),
       )
     else:
