@@ -14,9 +14,6 @@
 # limitations under the License.
 """Commands for reading and manipulating packet mirroring resources."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
