@@ -15,9 +15,6 @@
 
 """Implements the command for SSHing into an instance."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import argparse
 import datetime
