@@ -13,13 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Command group for Operations."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
-@base.UniverseCompatible
+@base.DefaultUniverseOnly
 class Operation(base.Group):
   """Backup for GKE Operations."""
+
+  category = base.UNCATEGORIZED_CATEGORY
