@@ -14,9 +14,6 @@
 # limitations under the License.
 """Update cluster command."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.container import api_adapter
@@ -110,6 +107,7 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
                     api_adapter.LUSTRECSIDRIVER: _ParseAddonDisabled,
                     api_adapter.CONFIGCONNECTOR: _ParseAddonDisabled,
                     api_adapter.RAYOPERATOR: _ParseAddonDisabled,
+                    api_adapter.SLURMOPERATOR: _ParseAddonDisabled,
                 },
                 **{k: _ParseAddonDisabled for k in api_adapter.CLOUDRUN_ADDONS}
             ),
@@ -169,6 +167,7 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
                     api_adapter.LUSTRECSIDRIVER: _ParseAddonDisabled,
                     api_adapter.CONFIGCONNECTOR: _ParseAddonDisabled,
                     api_adapter.RAYOPERATOR: _ParseAddonDisabled,
+                    api_adapter.SLURMOPERATOR: _ParseAddonDisabled,
                 },
                 **{k: _ParseAddonDisabled for k in api_adapter.CLOUDRUN_ADDONS}
             ),
@@ -224,6 +223,7 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
                     api_adapter.HIGHSCALECHECKPOINTING: _ParseAddonDisabled,
                     api_adapter.LUSTRECSIDRIVER: _ParseAddonDisabled,
                     api_adapter.RAYOPERATOR: _ParseAddonDisabled,
+                    api_adapter.SLURMOPERATOR: _ParseAddonDisabled,
                 },
                 **{k: _ParseAddonDisabled for k in api_adapter.CLOUDRUN_ADDONS}
             ),
@@ -241,8 +241,7 @@ def _AddMutuallyExclusiveArgs(mutex_group, release_track):
 {nodelocaldns}=ENABLED|DISABLED
 {gcepdcsidriver}=ENABLED|DISABLED
 {gcpfilestoredriver}=ENABLED|DISABLED
-{gcsfusecsidriver}=ENABLED|DISABLED
-""".format(
+{gcsfusecsidriver}=ENABLED|DISABLED""".format(
             hpa=api_adapter.HPA,
             ingress=api_adapter.INGRESS,
             dashboard=api_adapter.DASHBOARD,
@@ -365,6 +364,8 @@ class Update(base.UpdateCommand):
     )
     flags.AddBinauthzFlags(group, release_track=base.ReleaseTrack.GA)
     flags.AddEnableStackdriverKubernetesFlag(group)
+    flags.AddMaintenanceDisruptionBudgetFlagGroup(
+        group, hidden=False, is_update=True)
     flags.AddDailyMaintenanceWindowFlag(group, add_unset_text=True)
     flags.AddRecurringMaintenanceWindowFlags(group, is_update=True)
     flags.AddResourceUsageExportFlags(group, is_update=True)
@@ -410,6 +411,8 @@ class Update(base.UpdateCommand):
     flags.AddAutopilotWorkloadPoliciesFlag(group)
     flags.AddRemoveWorkloadPoliciesFlag(group)
     flags.AddRemoveAutopilotWorkloadPoliciesFlag(group)
+    flags.AddAutopilotClusterPoliciesFlag(group, hidden=True)
+    flags.AddRemoveAutopilotClusterPoliciesFlag(group, hidden=True)
     flags.AddEnableMultiNetworkingFlag(group)
     flags.AddContainerdConfigFlag(group)
     flags.AddAutoprovisioningResourceManagerTagsUpdate(group)
@@ -424,10 +427,14 @@ class Update(base.UpdateCommand):
     flags.AddEnableRayClusterLogging(group, is_update=True)
     flags.AddEnableRayClusterMonitoring(group, is_update=True)
     flags.AddSecretManagerEnableFlagGroup(group, is_update=True)
+    flags.AddSecretSyncFlagGroup(group, is_update=True, hidden=True)
     flags.AddInsecureRBACBindingFlags(group, hidden=False)
     group_add_additional_ip_ranges = group.add_group()
     flags.AddAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddRemoveAdditionalIpRangesFlag(group_add_additional_ip_ranges)
+    group_add_drain_additional_ip_ranges = group.add_group(hidden=True)
+    flags.AddDrainAdditionalIpRangesFlag(group_add_drain_additional_ip_ranges)
+    flags.AddUndrainAdditionalIpRangesFlag(group_add_drain_additional_ip_ranges)
     flags.AddClusterEnablePrivateNodesFlag(group)
     flags.AddDisableL4LbFirewallReconciliationFlag(group, is_update=True)
     flags.AddClusterTierFlag(group)
@@ -453,13 +460,14 @@ class Update(base.UpdateCommand):
     flags.AddPatchUpdateFlag(group)
     flags.AddAutoIpamFlag(group, is_update=True)
     flags.AddEnableLegacyLustrePortFlag(group, hidden=False)
+    flags.AddDisableMultiNicLustreFlag(group)
     flags.AddEnableDefaultComputeClassFlag(group)
     flags.AddNetworkTierFlag(group)
     flags.AddControlPlaneEgressFlag(group)
     flags.AddAutopilotPrivilegedAdmissionFlag(group, hidden=True)
-    flags.AddEnableKernelModuleSignatureEnforcementFlag(
-        group, for_node_pool=False, hidden=True
-    )
+    flags.AddEnableKernelModuleSignatureEnforcementFlag(group)
+    flags.AddEnableSliceControllerFlag(group, hidden=True)
+    flags.AddAutopilotGeneralProfileFlag(group)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -539,6 +547,8 @@ class Update(base.UpdateCommand):
     )
     opts.additional_ip_ranges = args.additional_ip_ranges
     opts.remove_additional_ip_ranges = args.remove_additional_ip_ranges
+    opts.drain_additional_ip_ranges = args.drain_additional_ip_ranges
+    opts.undrain_additional_ip_ranges = args.undrain_additional_ip_ranges
     opts.stack_type = args.stack_type
     opts.enable_cost_allocation = args.enable_cost_allocation
     opts.gateway_api = args.gateway_api
@@ -557,6 +567,10 @@ class Update(base.UpdateCommand):
     )
     opts.workload_policies = args.workload_policies
     opts.remove_workload_policies = args.remove_workload_policies
+    opts.autopilot_cluster_policies = args.autopilot_cluster_policies
+    opts.remove_autopilot_cluster_policies = (
+        args.remove_autopilot_cluster_policies
+    )
     opts.enable_multi_networking = args.enable_multi_networking
     opts.containerd_config_from_file = args.containerd_config_from_file
     opts.fleet_project = args.fleet_project
@@ -581,6 +595,9 @@ class Update(base.UpdateCommand):
     opts.secret_manager_rotation_interval = (
         args.secret_manager_rotation_interval
     )
+    opts.enable_secret_sync = args.enable_secret_sync
+    opts.enable_secret_sync_rotation = args.enable_secret_sync_rotation
+    opts.secret_sync_rotation_interval = args.secret_sync_rotation_interval
     opts.enable_insecure_binding_system_authenticated = (
         args.enable_insecure_binding_system_authenticated
     )
@@ -617,6 +634,7 @@ class Update(base.UpdateCommand):
     opts.enable_k8s_tokens_via_dns = args.enable_k8s_tokens_via_dns
     opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
     opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
+    opts.disable_multi_nic_lustre = args.disable_multi_nic_lustre
     opts.enable_default_compute_class = args.enable_default_compute_class
     opts.network_tier = args.network_tier
     opts.control_plane_egress_mode = args.control_plane_egress
@@ -627,6 +645,9 @@ class Update(base.UpdateCommand):
     opts.enable_kernel_module_signature_enforcement = (
         args.enable_kernel_module_signature_enforcement
     )
+    opts.enable_slice_controller = args.enable_slice_controller
+    opts.autopilot_general_profile = args.autopilot_general_profile
+    opts.enable_agent_sandbox = getattr(args, 'enable_agent_sandbox', None)
     return opts
 
   def Run(self, args):
@@ -840,6 +861,22 @@ to completion."""
         op_ref = adapter.SetLoggingService(cluster_ref, args.logging_service)
       except apitools_exceptions.HttpError as error:
         raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
+    elif (args.maintenance_minor_version_disruption_interval is not None or
+          args.maintenance_patch_version_disruption_interval is not None or
+          args.clear_maintenance_minor_version_disruption_interval is not None
+          or args.clear_maintenance_patch_version_disruption_interval is not
+          None):
+      try:
+        op_ref = adapter.SetMaintenanceDisruptionBudget(
+            cluster_ref,
+            cluster.maintenancePolicy,
+            args.maintenance_minor_version_disruption_interval,
+            args.maintenance_patch_version_disruption_interval,
+            args.clear_maintenance_minor_version_disruption_interval,
+            args.clear_maintenance_patch_version_disruption_interval,
+        )
+      except apitools_exceptions.HttpError as error:
+        raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
     elif args.maintenance_window is not None:
       try:
         op_ref = adapter.SetDailyMaintenanceWindow(
@@ -874,6 +911,20 @@ to completion."""
             args.add_maintenance_exclusion_start,
             args.add_maintenance_exclusion_end,
             args.add_maintenance_exclusion_scope,
+            args.add_maintenance_exclusion_until_end_of_support,
+        )
+      except apitools_exceptions.HttpError as error:
+        raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
+    elif args.add_maintenance_exclusion_until_end_of_support is not None:
+      try:
+        op_ref = adapter.AddMaintenanceExclusion(
+            cluster_ref,
+            cluster.maintenancePolicy,
+            args.add_maintenance_exclusion_name,
+            args.add_maintenance_exclusion_start,
+            None,
+            args.add_maintenance_exclusion_scope,
+            args.add_maintenance_exclusion_until_end_of_support,
         )
       except apitools_exceptions.HttpError as error:
         raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
@@ -986,6 +1037,14 @@ to completion."""
         )
       except apitools_exceptions.HttpError as error:
         raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
+    elif getattr(args, 'disable_multi_nic_lustre', None) is not None:
+      try:
+        op_ref = adapter.ModifyMultiNicLustreDisabled(
+            cluster_ref,
+            args.disable_multi_nic_lustre,
+        )
+      except apitools_exceptions.HttpError as error:
+        raise exceptions.HttpException(error, util.HTTP_ERROR_FORMAT)
     elif (
         getattr(args, 'enable_insecure_binding_system_authenticated', None)
         is not None
@@ -1150,7 +1209,12 @@ class UpdateBeta(Update):
     flags.AddAutoMonitoringScopeFlags(
         group_logging_monitoring_config, hidden=False
     )
-    flags.AddManagedOTelScopeFlags(group_logging_monitoring_config, hidden=True)
+    flags.AddManagedOTelScopeFlags(
+        group_logging_monitoring_config, hidden=False
+    )
+    flags.AddManagedMLDiagnosticsFlags(
+        group_logging_monitoring_config, hidden=True
+    )
     flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddEnableLoggingMonitoringSystemOnlyFlag(group)
     flags.AddEnableWorkloadMonitoringEapFlag(group)
@@ -1163,6 +1227,8 @@ class UpdateBeta(Update):
     flags.AddUpdateLabelsFlag(group)
     flags.AddRemoveLabelsFlag(group)
     flags.AddNetworkPolicyFlags(group)
+    flags.AddMaintenanceDisruptionBudgetFlagGroup(
+        group, hidden=False, is_update=True)
     flags.AddDailyMaintenanceWindowFlag(group, add_unset_text=True)
     flags.AddRecurringMaintenanceWindowFlags(group, is_update=True)
     flags.AddPodSecurityPolicyFlag(group)
@@ -1225,6 +1291,8 @@ class UpdateBeta(Update):
     flags.AddAutopilotWorkloadPoliciesFlag(group)
     flags.AddRemoveWorkloadPoliciesFlag(group)
     flags.AddRemoveAutopilotWorkloadPoliciesFlag(group)
+    flags.AddAutopilotClusterPoliciesFlag(group, hidden=True)
+    flags.AddRemoveAutopilotClusterPoliciesFlag(group, hidden=True)
     flags.AddEnableFqdnNetworkPolicyFlag(group)
     flags.AddHostMaintenanceIntervalFlag(group)
     flags.AddInTransitEncryptionFlag(group)
@@ -1245,6 +1313,9 @@ class UpdateBeta(Update):
     group_add_additional_ip_ranges = group.add_group()
     flags.AddAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddRemoveAdditionalIpRangesFlag(group_add_additional_ip_ranges)
+    group_add_drain_additional_ip_ranges = group.add_group(hidden=True)
+    flags.AddDrainAdditionalIpRangesFlag(group_add_drain_additional_ip_ranges)
+    flags.AddUndrainAdditionalIpRangesFlag(group_add_drain_additional_ip_ranges)
     flags.AddClusterEnablePrivateNodesFlag(group)
     flags.AddDisableL4LbFirewallReconciliationFlag(group, is_update=True)
     flags.AddClusterTierFlag(group)
@@ -1270,6 +1341,7 @@ class UpdateBeta(Update):
     flags.AddPatchUpdateFlag(group)
     flags.AddAutoIpamFlag(group, is_update=True)
     flags.AddEnableLegacyLustrePortFlag(group, hidden=False)
+    flags.AddDisableMultiNicLustreFlag(group)
     flags.AddEnableDefaultComputeClassFlag(group)
     group_fleet_flags = group.add_group()
     flags.AddFleetProjectFlag(group_fleet_flags, is_update=True)
@@ -1277,10 +1349,13 @@ class UpdateBeta(Update):
     flags.AddNetworkTierFlag(group)
     flags.AddControlPlaneEgressFlag(group)
     flags.AddAutopilotPrivilegedAdmissionFlag(group, hidden=True)
-    flags.AddPodSnapshotConfigFlags(group, hidden=True)
-    flags.AddEnableKernelModuleSignatureEnforcementFlag(
-        group, for_node_pool=True, hidden=True
-    )
+    flags.AddPodSnapshotConfigFlags(group, hidden=False)
+    flags.AddAgentSandboxConfigFlags(group, hidden=True)
+    flags.AddEnableKernelModuleSignatureEnforcementFlag(group)
+    flags.AddEnableSliceControllerFlag(group, hidden=True)
+    flags.AddAutopilotGeneralProfileFlag(group)
+    flags.AddLinkedRunnersModeFlag(group, hidden=True)
+    flags.AddNodePoolUpgradeConcurrencyConfigFlag(group, hidden=True)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1357,6 +1432,7 @@ class UpdateBeta(Update):
     opts.enable_workload_monitoring_eap = args.enable_workload_monitoring_eap
     opts.enable_managed_prometheus = args.enable_managed_prometheus
     opts.disable_managed_prometheus = args.disable_managed_prometheus
+    opts.enable_managed_mldiagnostics = args.enable_managed_mldiagnostics
     opts.auto_monitoring_scope = args.auto_monitoring_scope
     opts.disable_autopilot = args.disable_autopilot
     opts.enable_l4_ilb_subsetting = args.enable_l4_ilb_subsetting
@@ -1408,6 +1484,8 @@ class UpdateBeta(Update):
     )
     opts.additional_ip_ranges = args.additional_ip_ranges
     opts.remove_additional_ip_ranges = args.remove_additional_ip_ranges
+    opts.drain_additional_ip_ranges = args.drain_additional_ip_ranges
+    opts.undrain_additional_ip_ranges = args.undrain_additional_ip_ranges
     opts.gateway_api = args.gateway_api
     opts.fleet_project = args.fleet_project
     opts.enable_fleet = args.enable_fleet
@@ -1426,6 +1504,10 @@ class UpdateBeta(Update):
     )
     opts.workload_policies = args.workload_policies
     opts.remove_workload_policies = args.remove_workload_policies
+    opts.autopilot_cluster_policies = args.autopilot_cluster_policies
+    opts.remove_autopilot_cluster_policies = (
+        args.remove_autopilot_cluster_policies
+    )
     opts.enable_fqdn_network_policy = args.enable_fqdn_network_policy
     opts.host_maintenance_interval = args.host_maintenance_interval
     opts.enable_multi_networking = args.enable_multi_networking
@@ -1488,6 +1570,7 @@ class UpdateBeta(Update):
     opts.enable_k8s_tokens_via_dns = args.enable_k8s_tokens_via_dns
     opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
     opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
+    opts.disable_multi_nic_lustre = args.disable_multi_nic_lustre
     opts.enable_default_compute_class = args.enable_default_compute_class
     opts.network_tier = args.network_tier
     opts.control_plane_egress_mode = args.control_plane_egress
@@ -1498,6 +1581,11 @@ class UpdateBeta(Update):
     opts.enable_kernel_module_signature_enforcement = (
         args.enable_kernel_module_signature_enforcement
     )
+    opts.autopilot_general_profile = args.autopilot_general_profile
+    opts.node_pool_upgrade_concurrency_config = (
+        args.node_pool_upgrade_concurrency_config
+    )
+    opts.linked_runners_mode = args.linked_runners_mode
     return opts
 
 
@@ -1524,7 +1612,12 @@ class UpdateAlpha(Update):
     flags.AddAutoMonitoringScopeFlags(
         group_logging_monitoring_config, hidden=False
     )
-    flags.AddManagedOTelScopeFlags(group_logging_monitoring_config, hidden=True)
+    flags.AddManagedOTelScopeFlags(
+        group_logging_monitoring_config, hidden=False
+    )
+    flags.AddManagedMLDiagnosticsFlags(
+        group_logging_monitoring_config, hidden=True
+    )
     flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddEnableLoggingMonitoringSystemOnlyFlag(group)
     flags.AddEnableWorkloadMonitoringEapFlag(group)
@@ -1539,6 +1632,8 @@ class UpdateAlpha(Update):
     flags.AddNetworkPolicyFlags(group)
     flags.AddAutoprovisioningFlags(group, hidden=False, napless=True)
     flags.AddAutoscalingProfilesFlag(group)
+    flags.AddMaintenanceDisruptionBudgetFlagGroup(
+        group, hidden=False, is_update=True)
     flags.AddDailyMaintenanceWindowFlag(group, add_unset_text=True)
     flags.AddRecurringMaintenanceWindowFlags(group, is_update=True)
     flags.AddPodSecurityPolicyFlag(group)
@@ -1580,6 +1675,7 @@ class UpdateAlpha(Update):
     group_dataplane_v2_observability = group.add_group()
     flags.AddDataplaneV2MetricsFlag(group_dataplane_v2_observability)
     flags.AddDataplaneV2ObservabilityFlags(group_dataplane_v2_observability)
+    flags.AddEnableAmbientNetworkingFlag(group, is_update=True)
     flags.AddWorkloadConfigAuditFlag(group)
     flags.AddHPAProfilesFlag(group)
     flags.AddWorkloadVulnScanningFlag(group)
@@ -1600,6 +1696,8 @@ class UpdateAlpha(Update):
     flags.AddAutopilotWorkloadPoliciesFlag(group)
     flags.AddRemoveWorkloadPoliciesFlag(group)
     flags.AddRemoveAutopilotWorkloadPoliciesFlag(group)
+    flags.AddAutopilotClusterPoliciesFlag(group, hidden=True)
+    flags.AddRemoveAutopilotClusterPoliciesFlag(group, hidden=True)
     flags.AddEnableFqdnNetworkPolicyFlag(group)
     flags.AddHostMaintenanceIntervalFlag(group)
     flags.AddInTransitEncryptionFlag(group)
@@ -1620,6 +1718,9 @@ class UpdateAlpha(Update):
     group_add_additional_ip_ranges = group.add_group()
     flags.AddAdditionalIpRangesFlag(group_add_additional_ip_ranges)
     flags.AddRemoveAdditionalIpRangesFlag(group_add_additional_ip_ranges)
+    group_add_drain_additional_ip_ranges = group.add_group(hidden=True)
+    flags.AddDrainAdditionalIpRangesFlag(group_add_drain_additional_ip_ranges)
+    flags.AddUndrainAdditionalIpRangesFlag(group_add_drain_additional_ip_ranges)
     flags.AddClusterEnablePrivateNodesFlag(group)
     flags.AddDisableL4LbFirewallReconciliationFlag(group, is_update=True)
     flags.AddClusterTierFlag(group)
@@ -1645,6 +1746,7 @@ class UpdateAlpha(Update):
     flags.AddPatchUpdateFlag(group)
     flags.AddAutoIpamFlag(group, is_update=True)
     flags.AddEnableLegacyLustrePortFlag(group, hidden=False)
+    flags.AddDisableMultiNicLustreFlag(group)
     flags.AddEnableDefaultComputeClassFlag(group)
     group_fleet_flags = group.add_group()
     flags.AddFleetProjectFlag(group_fleet_flags, is_update=True)
@@ -1652,10 +1754,13 @@ class UpdateAlpha(Update):
     flags.AddNetworkTierFlag(group)
     flags.AddControlPlaneEgressFlag(group)
     flags.AddAutopilotPrivilegedAdmissionFlag(group, hidden=True)
-    flags.AddPodSnapshotConfigFlags(group, hidden=True)
-    flags.AddEnableKernelModuleSignatureEnforcementFlag(
-        group, for_node_pool=True, hidden=True
-    )
+    flags.AddPodSnapshotConfigFlags(group, hidden=False)
+    flags.AddAgentSandboxConfigFlags(group, hidden=True)
+    flags.AddEnableKernelModuleSignatureEnforcementFlag(group)
+    flags.AddEnableSliceControllerFlag(group, hidden=True)
+    flags.AddAutopilotGeneralProfileFlag(group)
+    flags.AddLinkedRunnersModeFlag(group, hidden=True)
+    flags.AddNodePoolUpgradeConcurrencyConfigFlag(group, hidden=True)
 
   def ParseUpdateOptions(self, args, locations):
     get_default = lambda key: getattr(args, key)
@@ -1729,6 +1834,7 @@ class UpdateAlpha(Update):
     opts.enable_workload_monitoring_eap = args.enable_workload_monitoring_eap
     opts.enable_managed_prometheus = args.enable_managed_prometheus
     opts.disable_managed_prometheus = args.disable_managed_prometheus
+    opts.enable_managed_mldiagnostics = args.enable_managed_mldiagnostics
     opts.auto_monitoring_scope = args.auto_monitoring_scope
     opts.disable_autopilot = args.disable_autopilot
     opts.enable_l4_ilb_subsetting = args.enable_l4_ilb_subsetting
@@ -1753,6 +1859,7 @@ class UpdateAlpha(Update):
     opts.enable_image_streaming = args.enable_image_streaming
     opts.maintenance_interval = args.maintenance_interval
     opts.dataplane_v2 = args.enable_dataplane_v2
+    opts.enable_ambient_networking = args.enable_ambient_networking
     opts.enable_dataplane_v2_metrics = args.enable_dataplane_v2_metrics
     opts.disable_dataplane_v2_metrics = args.disable_dataplane_v2_metrics
     opts.enable_dataplane_v2_flow_observability = (
@@ -1780,6 +1887,8 @@ class UpdateAlpha(Update):
     )
     opts.additional_ip_ranges = args.additional_ip_ranges
     opts.remove_additional_ip_ranges = args.remove_additional_ip_ranges
+    opts.drain_additional_ip_ranges = args.drain_additional_ip_ranges
+    opts.undrain_additional_ip_ranges = args.undrain_additional_ip_ranges
     opts.fleet_project = args.fleet_project
     opts.enable_fleet = args.enable_fleet
     opts.membership_type = args.membership_type
@@ -1797,6 +1906,10 @@ class UpdateAlpha(Update):
     )
     opts.workload_policies = args.workload_policies
     opts.remove_workload_policies = args.remove_workload_policies
+    opts.autopilot_cluster_policies = args.autopilot_cluster_policies
+    opts.remove_autopilot_cluster_policies = (
+        args.remove_autopilot_cluster_policies
+    )
     opts.enable_fqdn_network_policy = args.enable_fqdn_network_policy
     opts.host_maintenance_interval = args.host_maintenance_interval
     opts.enable_multi_networking = args.enable_multi_networking
@@ -1859,6 +1972,7 @@ class UpdateAlpha(Update):
     opts.enable_k8s_tokens_via_dns = args.enable_k8s_tokens_via_dns
     opts.enable_k8s_certs_via_dns = args.enable_k8s_certs_via_dns
     opts.enable_legacy_lustre_port = args.enable_legacy_lustre_port
+    opts.disable_multi_nic_lustre = args.disable_multi_nic_lustre
     opts.enable_default_compute_class = args.enable_default_compute_class
     opts.network_tier = args.network_tier
     opts.control_plane_egress_mode = args.control_plane_egress
@@ -1869,4 +1983,9 @@ class UpdateAlpha(Update):
     opts.enable_kernel_module_signature_enforcement = (
         args.enable_kernel_module_signature_enforcement
     )
+    opts.autopilot_general_profile = args.autopilot_general_profile
+    opts.node_pool_upgrade_concurrency_config = (
+        args.node_pool_upgrade_concurrency_config
+    )
+    opts.linked_runners_mode = args.linked_runners_mode
     return opts
