@@ -14,9 +14,6 @@
 # limitations under the License.
 """Update node pool command."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.compute import utils
@@ -73,6 +70,7 @@ class Update(base.UpdateCommand):
     _Args(parser)
     group = parser.add_mutually_exclusive_group(required=True)
 
+    flags.AddNodePoolDatapathProviderFlags(group)
     flags.AddNodePoolLocationsFlag(group)
 
     node_management_group = group.add_argument_group('Node management')
@@ -107,6 +105,9 @@ class Update(base.UpdateCommand):
     flags.AddLabelsFlag(group, for_node_pool=True)
     flags.AddNodeLabelsFlag(group, for_node_pool=True, for_update=True)
     flags.AddNodeTaintsFlag(group, for_node_pool=True, for_update=True)
+    flags.AddNodeArchitectureTaintBehaviorFlag(
+        group, for_node_pool=True, for_update=True
+    )
     flags.AddTagsNodePoolUpdate(group)
     flags.AddEnableGvnicFlag(group)
     flags.AddEnableImageStreamingFlag(group, for_node_pool=True)
@@ -123,7 +124,7 @@ class Update(base.UpdateCommand):
         group, for_node_pool=True, for_create=False)
     flags.AddResourceManagerTagsNodePoolUpdate(group)
     flags.AddQueuedProvisioningFlag(group)
-    flags.AddConsolidationDelayFlag(group, hidden=True)
+    flags.AddConsolidationDelayFlag(group)
     flags.AddMaxRunDurationFlag(group)
     flags.AddFlexStartFlag(group)
     flags.AddEnableKubeletReadonlyPortFlag(group)
@@ -136,6 +137,7 @@ class Update(base.UpdateCommand):
     flags.AddEnableKernelModuleSignatureEnforcementFlag(
         group, for_node_pool=True
     )
+    flags.AddNodeDrainSettingsFlag(group)
     flags.AddEnableLustreMultiRailFlag(group, for_node_pool=True, hidden=True)
 
   def ParseUpdateNodePoolOptions(self, args):
@@ -192,7 +194,12 @@ class Update(base.UpdateCommand):
         boot_disk_provisioned_iops=args.boot_disk_provisioned_iops,
         boot_disk_provisioned_throughput=args.boot_disk_provisioned_throughput,
         enable_kernel_module_signature_enforcement=args.enable_kernel_module_signature_enforcement,
+        node_drain_grace_period=args.node_drain_grace_period_seconds,
+        node_drain_pdb_timeout=args.node_drain_pdb_timeout_seconds,
+        respect_pdb_during_node_pool_deletion=args.respect_pdb_during_node_pool_deletion,
         enable_lustre_multi_nic=args.enable_lustre_multi_nic,
+        datapath_provider=args.datapath_provider,
+        node_architecture_taint_behavior=args.node_architecture_taint_behavior,
     )
 
   def Run(self, args):
@@ -275,6 +282,7 @@ class UpdateBeta(Update):
     _Args(parser)
     group = parser.add_mutually_exclusive_group(required=True)
 
+    flags.AddNodePoolDatapathProviderFlags(group)
     node_management_group = group.add_argument_group('Node management')
     flags.AddEnableAutoRepairFlag(node_management_group, for_node_pool=True)
     flags.AddEnableAutoUpgradeFlag(node_management_group, for_node_pool=True)
@@ -311,6 +319,9 @@ class UpdateBeta(Update):
     flags.AddLabelsFlag(group, for_node_pool=True)
     flags.AddNodeLabelsFlag(group, for_node_pool=True, for_update=True)
     flags.AddNodeTaintsFlag(group, for_node_pool=True, for_update=True)
+    flags.AddNodeArchitectureTaintBehaviorFlag(
+        group, for_node_pool=True, for_update=True
+    )
     flags.AddTagsNodePoolUpdate(group)
     flags.AddNodePoolEnablePrivateNodes(group)
     flags.AddEnableGcfsFlag(group, for_node_pool=True)
@@ -328,7 +339,7 @@ class UpdateBeta(Update):
     flags.AddStoragePoolsFlag(
         group, for_node_pool=True, for_create=False)
     flags.AddQueuedProvisioningFlag(group)
-    flags.AddConsolidationDelayFlag(group, hidden=True)
+    flags.AddConsolidationDelayFlag(group, hidden=False)
     flags.AddMaxRunDurationFlag(group)
     flags.AddFlexStartFlag(group)
     flags.AddEnableKubeletReadonlyPortFlag(group)
@@ -339,6 +350,7 @@ class UpdateBeta(Update):
     flags.AddDiskSizeFlag(node_config_group)
     flags.AddBootDiskProvisionedThroughputFlag(node_config_group)
     flags.AddBootDiskProvisionedIopsFlag(node_config_group)
+    flags.AddNodeDrainSettingsFlag(group)
 
     flags.AddEnableKernelModuleSignatureEnforcementFlag(
         group, for_node_pool=True
@@ -400,7 +412,12 @@ class UpdateBeta(Update):
         boot_disk_provisioned_iops=args.boot_disk_provisioned_iops,
         boot_disk_provisioned_throughput=args.boot_disk_provisioned_throughput,
         enable_kernel_module_signature_enforcement=args.enable_kernel_module_signature_enforcement,
+        node_drain_grace_period=args.node_drain_grace_period_seconds,
+        node_drain_pdb_timeout=args.node_drain_pdb_timeout_seconds,
+        respect_pdb_during_node_pool_deletion=args.respect_pdb_during_node_pool_deletion,
         enable_lustre_multi_nic=args.enable_lustre_multi_nic,
+        datapath_provider=args.datapath_provider,
+        node_architecture_taint_behavior=args.node_architecture_taint_behavior,
     )
     return ops
 
@@ -414,6 +431,7 @@ class UpdateAlpha(Update):
     _Args(parser)
     group = parser.add_mutually_exclusive_group(required=True)
 
+    flags.AddNodePoolDatapathProviderFlags(group)
     node_management_group = group.add_argument_group('Node management')
     flags.AddEnableAutoRepairFlag(node_management_group, for_node_pool=True)
     flags.AddEnableAutoUpgradeFlag(node_management_group, for_node_pool=True)
@@ -450,6 +468,9 @@ class UpdateAlpha(Update):
     flags.AddLabelsFlag(group, for_node_pool=True)
     flags.AddNodeLabelsFlag(group, for_node_pool=True, for_update=True)
     flags.AddNodeTaintsFlag(group, for_node_pool=True, for_update=True)
+    flags.AddNodeArchitectureTaintBehaviorFlag(
+        group, for_node_pool=True, for_update=True
+    )
     flags.AddTagsNodePoolUpdate(group)
     flags.AddNodePoolEnablePrivateNodes(group)
     flags.AddEnableGcfsFlag(group, for_node_pool=True)
@@ -467,7 +488,7 @@ class UpdateAlpha(Update):
     flags.AddStoragePoolsFlag(
         group, for_node_pool=True, for_create=False)
     flags.AddQueuedProvisioningFlag(group)
-    flags.AddConsolidationDelayFlag(group, hidden=True)
+    flags.AddConsolidationDelayFlag(group, hidden=False)
     flags.AddMaxRunDurationFlag(group)
     flags.AddFlexStartFlag(group)
     flags.AddEnableKubeletReadonlyPortFlag(group)
@@ -478,6 +499,7 @@ class UpdateAlpha(Update):
     flags.AddDiskSizeFlag(node_config_group)
     flags.AddBootDiskProvisionedThroughputFlag(node_config_group)
     flags.AddBootDiskProvisionedIopsFlag(node_config_group)
+    flags.AddNodeDrainSettingsFlag(group)
 
     flags.AddEnableKernelModuleSignatureEnforcementFlag(
         group, for_node_pool=True
@@ -539,7 +561,12 @@ class UpdateAlpha(Update):
         boot_disk_provisioned_iops=args.boot_disk_provisioned_iops,
         boot_disk_provisioned_throughput=args.boot_disk_provisioned_throughput,
         enable_kernel_module_signature_enforcement=args.enable_kernel_module_signature_enforcement,
+        node_drain_grace_period=args.node_drain_grace_period_seconds,
+        node_drain_pdb_timeout=args.node_drain_pdb_timeout_seconds,
+        respect_pdb_during_node_pool_deletion=args.respect_pdb_during_node_pool_deletion,
         enable_lustre_multi_nic=args.enable_lustre_multi_nic,
+        datapath_provider=args.datapath_provider,
+        node_architecture_taint_behavior=args.node_architecture_taint_behavior,
     )
     return ops
 
