@@ -16,9 +16,6 @@
 """The command group for gcloud dataflow metrics.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
