@@ -14,9 +14,6 @@
 # limitations under the License.
 """gcloud datastore emulator start command."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import socket
 from googlecloudsdk.calliope import arg_parsers
@@ -24,7 +21,6 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.emulators import firestore_util
 from googlecloudsdk.command_lib.emulators import util
 from googlecloudsdk.command_lib.util import java
-from googlecloudsdk.core import log
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
@@ -115,25 +111,6 @@ class Start(base.Command):
         help='If set, the emulator will print open-source dependencies and '
         'licenses, then exit.')
 
-  # TODO(b/354923511): Remove this warning after b/354923511 is fixed.
-  def LogJavaVersionWarning(self):
-    """Log a warning message notifying users about Java version change.
-
-    Log the warning when the installed JRE has an earlier version than Java 21.
-    """
-    try:
-      java.RequireJavaInstalled(firestore_util.FIRESTORE_TITLE, min_version=21)
-    except java.JavaVersionError:
-      log.warning(
-          'Cloud Firestore Emulator support for Java JRE version 11 will be '
-          'dropped after gcloud command-line tool release 528.0.0. Please '
-          'upgrade to Java JRE version 21 or higher to continue using the '
-          'latest Cloud Firestore Emulator.')
-    except java.JavaError:
-      # A JRE could not be found. Not logging the warning since the user will
-      # not be able to start an emulator anyways.
-      pass
-
   def Run(self, args):
     if not args.host_port:
       args.host_port = arg_parsers.HostPort.Parse(
@@ -142,7 +119,6 @@ class Start(base.Command):
     args.host_port.port = args.host_port.port or '8080'
     args.database_mode = args.database_mode or 'firestore-native'
     firestore_util.ValidateStartArgs(args)
-    self.LogJavaVersionWarning()
-    java.RequireJavaInstalled(firestore_util.FIRESTORE_TITLE, min_version=11)
+    java.RequireJavaInstalled(firestore_util.FIRESTORE_TITLE, min_version=21)
     with firestore_util.StartFirestoreEmulator(args) as proc:
       util.PrefixOutput(proc, 'firestore')
