@@ -14,14 +14,14 @@
 # limitations under the License.
 """The gke-destinations command group for Eventarc."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
 
 @base.Hidden
 @base.ReleaseTracks(base.ReleaseTrack.GA)
+@base.DefaultUniverseOnly
 class GKEDestinations(base.Group):
   """Manage Eventarc with Cloud Run for Anthos/GKE destinations."""
+
+  category = base.SERVERLESS_CATEGORY
