@@ -14,9 +14,6 @@
 # limitations under the License.
 """The kafka sources command group for Eventarc."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
@@ -26,3 +23,5 @@ from googlecloudsdk.calliope import base
 @base.Hidden
 class KafkaSources(base.Group):
   """Manage Eventarc kafka sources."""
+
+  category = base.SERVERLESS_CATEGORY
