@@ -14,9 +14,6 @@
 # limitations under the License.
 """The locations command group for Eventarc."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
@@ -25,3 +22,5 @@ from googlecloudsdk.calliope import base
 @base.DefaultUniverseOnly
 class Locations(base.Group):
   """Explore locations available for Eventarc."""
+
+  category = base.SERVERLESS_CATEGORY
