@@ -14,9 +14,6 @@
 # limitations under the License.
 """Command to create a pipeline."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.eventarc import pipelines
 from googlecloudsdk.calliope import base
@@ -107,12 +104,14 @@ class Create(base.CreateCommand):
 
   @classmethod
   def Args(cls, parser):
-    flags.AddCreatePipelineResourceArgs(parser)
+    flags.AddPipelineResourceArg(
+        parser, 'The pipeline to create.', required=True
+    )
     flags.AddPipelineDestinationsArg(parser, required=True)
     flags.AddInputPayloadFormatArgs(parser)
     flags.AddMediationsArg(parser)
     flags.AddLoggingConfigArg(parser, 'The logging config of the pipeline.')
-    flags.AddRetryPolicyArgs(parser)
+    flags.AddPipelineRetryPolicyArgs(parser)
     flags.AddCryptoKeyArg(parser, with_clear=False, hidden=False)
     labels_util.AddCreateLabelsFlags(parser)
     base.ASYNC_FLAG.AddToParser(parser)
@@ -121,7 +120,6 @@ class Create(base.CreateCommand):
     """Run the create command."""
     client = pipelines.PipelineClientV1()
     pipelines_ref = args.CONCEPTS.pipeline.Parse()
-    error_message_bus_ref = args.CONCEPTS.error_message_bus.Parse()
 
     log.debug(
         'Creating pipeline {} for project {} in location {}'.format(
@@ -145,7 +143,6 @@ class Create(base.CreateCommand):
             max_retry_delay=args.max_retry_delay,
             crypto_key_name=args.crypto_key,
             labels=labels_util.ParseCreateArgs(args, client.LabelsValueClass()),
-            error_message_bus_ref=error_message_bus_ref,
         ),
     )
 
