@@ -13,9 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Upgrade a 1st gen Cloud Function to the Cloud Run function."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import collections
 
@@ -34,6 +31,11 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core.console import console_io
 import six
 
+SUPPORTED_EVENT_TYPES = (
+    'google.pubsub.topic.publish',
+    'providers/cloud.pubsub/eventTypes/topic.publish',
+)
+
 UpgradeAction = collections.namedtuple(
     'UpgradeAction',
     [
@@ -137,6 +139,23 @@ _COMMIT_ACTION = UpgradeAction(
     ),
 )
 
+_COMMIT_AS_GEN2_ACTION = UpgradeAction(
+    target_state='COMMIT_FUNCTION_UPGRADE_AS_GEN2_SUCCESSFUL',
+    prompt_msg=(
+        'This will complete the upgrade process for function [{}] and delete'
+        ' the 1st gen copy.\n\nThis action cannot be undone.'
+    ),
+    op_description=(
+        'Completing the upgrade and deleting the 1st gen copy for function.'
+    ),
+    success_msg=(
+        'Upgrade completed and the 1st gen copy was successfully'
+        ' deleted.\n\nYour function will continue to be available at the'
+        ' following endpoints:\n{}\nReminder, your function can now be managed'
+        ' through the Cloud Run API.'
+    ),
+)
+
 # Source: http://cs/f:UpgradeStateMachine.java
 _VALID_TRANSITION_ACTIONS = {
     'ELIGIBLE_FOR_2ND_GEN_UPGRADE': [_SETUP_CONFIG_ACTION],
@@ -152,6 +171,7 @@ _VALID_TRANSITION_ACTIONS = {
     'ABORT_FUNCTION_UPGRADE_ERROR': [_ABORT_ACTION],
     'REDIRECT_FUNCTION_UPGRADE_TRAFFIC_SUCCESSFUL': [
         _COMMIT_ACTION,
+        _COMMIT_AS_GEN2_ACTION,
         _ROLLBACK_TRAFFIC_ACTION,
         _ABORT_ACTION,
     ],
@@ -164,8 +184,15 @@ _VALID_TRANSITION_ACTIONS = {
         _ABORT_ACTION,
     ],
     'COMMIT_FUNCTION_UPGRADE_SUCCESSFUL': [],
+    'COMMIT_FUNCTION_UPGRADE_ERROR_ROLLBACK_SAFE': [
+        _COMMIT_ACTION,
+        _ROLLBACK_TRAFFIC_ACTION,
+        _ABORT_ACTION,
+    ],
     'COMMIT_FUNCTION_UPGRADE_ERROR': [_COMMIT_ACTION],
-}  # type: dict[str, UpgradeAction]
+    'COMMIT_FUNCTION_UPGRADE_AS_GEN2_SUCCESSFUL': [],
+    'COMMIT_FUNCTION_UPGRADE_AS_GEN2_ERROR': [_COMMIT_AS_GEN2_ACTION],
+}  # type: dict[str, list[UpgradeAction]]
 
 
 def _ValidateStateTransition(upgrade_state, action):
@@ -192,10 +219,44 @@ def _ValidateStateTransition(upgrade_state, action):
     )
 
 
-@base.Hidden
+# Source: http://cs/f:Gen1UpgradeEligibilityValidator.java
+def _RaiseNotEligibleForUpgradeError(function):
+  """Raises an error when the function is not eligible for upgrade."""
+  if six.text_type(function.environment) == 'GEN_2':
+    raise exceptions.FunctionsError(
+        f'Function [{function.name}] is not eligible for Upgrade. To migrate to'
+        ' Cloud Run function, please detach the function using `gcloud'
+        ' functions detach` instead.'
+    )
+  if ':' in api_util.GetProject():
+    raise exceptions.FunctionsError(
+        f'Function [{function.name}] is not eligible for Cloud Run function'
+        ' upgrade. It is in domain-scoped project that Cloud Run does not'
+        ' support.'
+    )
+  if six.text_type(function.state) != 'ACTIVE':
+    raise exceptions.FunctionsError(
+        f'Function [{function.name}] is not eligible for Cloud Run function'
+        f' upgrade. It is in state [{function.state}].'
+    )
+  if (
+      not function.url
+      and function.eventTrigger.eventType not in SUPPORTED_EVENT_TYPES
+  ):
+    raise exceptions.FunctionsError(
+        f'Function [{function.name}] is not eligible for Cloud Run function'
+        ' upgrade. Only HTTP functions and Pub/Sub triggered functions are'
+        ' supported.'
+    )
+  raise exceptions.FunctionsError(
+      f'Function [{function.name}] is not eligible for Cloud Run function'
+      ' upgrade.'
+  )
+
+
 @base.DefaultUniverseOnly
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class UpgradeAlpha(base.Command):
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class UpgradeBeta(base.Command):
   """Upgrade a 1st gen Cloud Function to the Cloud Run function."""
 
   detailed_help = {
@@ -226,7 +287,7 @@ class UpgradeAlpha(base.Command):
   @staticmethod
   def Args(parser):
     flags.AddFunctionResourceArg(parser, 'to upgrade')
-    flags.AddUpgradeFlags(parser)
+    flags.AddUpgradeFlags(parser, release_track=base.ReleaseTrack.BETA)
 
   def Run(self, args):
     client = client_v2.FunctionsClient(self.ReleaseTrack())
@@ -241,15 +302,22 @@ class UpgradeAlpha(base.Command):
       )
 
     if not function.upgradeInfo:
-      # TODO(b/271030987): Provide additional info on why a function is not
-      # eligible for an upgrade.
-      raise exceptions.FunctionsError(
-          'Function [{}] is not eligible for Cloud Run function upgrade.'
-          .format(function_name)
-      )
+      _RaiseNotEligibleForUpgradeError(function)
 
     upgrade_state = function.upgradeInfo.upgradeState
 
+    if (
+        six.text_type(upgrade_state)
+        == 'INELIGIBLE_FOR_UPGRADE_UNTIL_REDEPLOYMENT'
+    ):
+      raise exceptions.FunctionsError(
+          f'Function [{function.name}] is not eligible for Cloud Run function'
+          f' upgrade. The runtime [{function.buildConfig.runtime}] is not'
+          ' supported. Please update to a supported runtime instead and try'
+          ' again. Use `gcloud functions runtimes list` to get a list of'
+          ' available runtimes.'
+      )
+
     action = None
     action_fn = None
     if args.redirect_traffic:
@@ -259,8 +327,12 @@ class UpgradeAlpha(base.Command):
       action = _ROLLBACK_TRAFFIC_ACTION
       action_fn = client.RollbackFunctionUpgradeTraffic
     elif args.commit:
-      action = _COMMIT_ACTION
-      action_fn = client.CommitFunctionUpgrade
+      if getattr(args, 'skip_detach', False):
+        action = _COMMIT_AS_GEN2_ACTION
+        action_fn = client.CommitFunctionUpgradeAsGen2
+      else:
+        action = _COMMIT_ACTION
+        action_fn = client.CommitFunctionUpgrade
     elif args.abort:
       action = _ABORT_ACTION
       action_fn = client.AbortFunctionUpgrade
@@ -303,7 +375,12 @@ class UpgradeAlpha(base.Command):
         deploy_util.ensure_pubsub_sa_has_token_creator_role()
       if trigger and trigger_types.IsAuditLogType(trigger.eventType):
         deploy_util.ensure_data_access_logs_are_enabled(trigger.eventFilters)
-      operation = action_fn(function_name, args.trigger_service_account)
+      operation = action_fn(
+          function_name,
+          trigger_service_account=args.trigger_service_account,
+          runtime=getattr(args, 'runtime', None),
+          max_instances=getattr(args, 'max_instances', None),
+      )
     else:
       operation = action_fn(function_name)
 
@@ -328,9 +405,20 @@ class UpgradeAlpha(base.Command):
       log.status.Print(
           action.success_msg.format(function.upgradeInfo.serviceConfig.uri)
       )
-    elif action == _COMMIT_ACTION:
+    elif action in (_COMMIT_ACTION, _COMMIT_AS_GEN2_ACTION):
       service = run_util.GetService(function)
       urls_strings = ''.join(f'* {url}\n' for url in service.urls)
       log.status.Print(action.success_msg.format(urls_strings))
     else:
       log.status.Print(action.success_msg)
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class UpgradeAlpha(UpgradeBeta):
+  """Upgrade a 1st gen Cloud Function to the Cloud Run function."""
+
+  @staticmethod
+  def Args(parser):
+    flags.AddFunctionResourceArg(parser, 'to upgrade')
+    flags.AddUpgradeFlags(parser, release_track=base.ReleaseTrack.ALPHA)
