@@ -23,9 +23,6 @@ for this command tree.  You can implement methods in this class to override some
 of the default behavior.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
