@@ -14,9 +14,6 @@
 # limitations under the License.
 """'logging operations list' command."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.logging import util
 from googlecloudsdk.calliope import arg_parsers
@@ -47,6 +44,14 @@ class List(base.ListCommand):
             universe_help='Not all operation types are supported.\n',
         ),
     )
+    parser.add_argument(
+        '--page-token',
+        type=str,
+        help=(
+            'The next_page_token value returned from a previous List request,'
+            ' if any.'
+        ),
+    )
     base.URI_FLAG.RemoveFromParser(parser)
     base.FILTER_FLAG.RemoveFromParser(parser)
 
@@ -66,7 +71,11 @@ class List(base.ListCommand):
         util.GetParentFromArgs(args), 'locations', args.location)
 
     request = util.GetMessages().LoggingProjectsLocationsOperationsListRequest(
-        name=operation_name, filter=args.operation_filter)
+        name=operation_name,
+        filter=args.operation_filter,
+        pageSize=args.page_size,
+        pageToken=args.page_token,
+    )
 
     result = util.GetClient().projects_locations_operations.List(request)
     self._cancellation_requested = False
@@ -76,6 +85,8 @@ class List(base.ListCommand):
         serialize_op = resource_projector.MakeSerializable(operation)
         self._cancellation_requested = serialize_op.get('metadata', {}).get(
             'cancellationRequested', '')
+    if result.nextPageToken:
+      yield result.nextPageToken
 
   def Epilog(self, resources_were_displayed):
     if self._cancellation_requested:
