@@ -14,14 +14,12 @@
 # limitations under the License.
 """Managed Service for Apache Kafka connect-clusters operations."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
 @base.DefaultUniverseOnly
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class ConnectClusters(base.Group):
   """Administer Managed Service for Apache Kafka connect-clusters."""
 
