@@ -15,9 +15,6 @@
 
 """Command group for ml language."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
