@@ -14,16 +14,20 @@
 # limitations under the License.
 """Command sub-group for Secure Access Connect attachment endpoints."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
 
 @base.DefaultUniverseOnly
 @base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
-class Attachments(base.Group):
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class AttachmentsAlpha(base.Group):
+  """Manage Secure Access Connect attachments."""
+  category = base.NETWORK_SECURITY_CATEGORY
+
+
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class AttachmentsBeta(base.Group):
   """Manage Secure Access Connect attachments."""
   category = base.NETWORK_SECURITY_CATEGORY
