@@ -14,15 +14,13 @@
 # limitations under the License.
 """Command group for backup collections of Cloud Memorystore Cluster for Redis."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA,
-                    base.ReleaseTrack.BETA)
+                    base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 @base.DefaultUniverseOnly
 class BackupCollections(base.Group):
   """Manage backup collections of Memorystore for Redis Cluster instances."""
