@@ -14,9 +14,6 @@
 # limitations under the License.
 """The group for the Cloud Folders CLI."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.resource_manager import folders
 from googlecloudsdk.calliope import base
