@@ -14,9 +14,6 @@
 # limitations under the License.
 """Create a new secret."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.secrets import api as secrets_api
 from googlecloudsdk.calliope import base
@@ -32,7 +29,7 @@ from googlecloudsdk.core.console import console_io
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
-@base.DefaultUniverseOnly
+@base.UniverseCompatible
 class Create(base.CreateCommand):
   # pylint: disable=line-too-long
   r"""Create a new secret.
