@@ -14,15 +14,13 @@
 # limitations under the License.
 """Command group for spanner databases sessions."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA,
                     base.ReleaseTrack.ALPHA)
+@base.UniverseCompatible
 class Sessions(base.Group):
   """Manage the sessions for Cloud Spanner databases."""
   pass
