@@ -14,9 +14,6 @@
 # limitations under the License.
 """Command for spanner instance partitions delete."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import textwrap
 
@@ -27,12 +24,12 @@ from googlecloudsdk.command_lib.spanner import resource_args
 from googlecloudsdk.core.console import console_io
 
 
-@base.DefaultUniverseOnly
 @base.ReleaseTracks(
     base.ReleaseTrack.GA, base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA
 )
+@base.UniverseCompatible
 class Delete(base.DeleteCommand):
-  """Delete a Spanner instance partition."""
+  """Delete a Spanner instance partition. You can't delete the default instance partition using this command."""  # pylint: disable=line-too-long
 
   detailed_help = {
       'EXAMPLES': textwrap.dedent("""\
