@@ -14,9 +14,6 @@
 # limitations under the License.
 """Creates a new Cloud SQL instance."""
 # TODO(b/362481808): remove python2-isms.
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.sql import api_util as common_api_util
@@ -165,9 +162,11 @@ def AddBaseArgs(parser):
   flags.AddForceSqlNetworkArchitecture(parser)
   flags.AddFinalBackup(parser)
   flags.AddFinalbackupRetentionDays(parser)
+  flags.AddServerCertificateRotationMode(parser)
   flags.AddEnableConnectionPooling(parser)
   flags.AddConnectionPoolFlags(parser)
   flags.AddReadPoolAutoScaleConfig(parser)
+  flags.AddDataApiAccess(parser)
 
   # When adding a new field for instance creation, determine if it should also
   # be included in the restore to new instance command. This command uses backup
@@ -185,10 +184,9 @@ def AddBetaArgs(parser):
   flags.AddReplicationLagMaxSecondsForRecreate(parser)
   flags.AddEnableDbAlignedAtomicWrites(parser)
   flags.AddEnableAcceleratedReplicaMode(parser)
-  flags.AddDataApiAccess(parser)
-  flags.AddServerCertificateRotationMode(parser)
-  flags.AddPerformanceCaptureConfig(parser, hidden=True)
+  flags.AddPerformanceCaptureConfig(parser, hidden=False)
   flags.AddUncMappings(parser)
+  flags.AddSqlServerEntraId(parser)
 
 
 def AddAlphaArgs(unused_parser):
