@@ -14,9 +14,6 @@
 # limitations under the License.
 
 """Performs pre-checks for a major version upgrade of a Cloud SQL instance."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import time
 
@@ -46,8 +43,6 @@ DETAILED_HELP = {
 }
 
 
-# TODO(b/425850257): remove Hidden label once we are ready to launch.
-@base.Hidden
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 @base.UniverseCompatible
 class PreCheckMajorVersionUpgrade(base.Command):
