@@ -14,14 +14,10 @@
 # limitations under the License.
 """The command group for the VMware Engine datastore CLI."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
 
 
-@base.Hidden
 @base.DefaultUniverseOnly
 @base.ReleaseTracks(base.ReleaseTrack.GA)
 class Datastores(base.Group):
